@@ -73,7 +73,11 @@
 
 /*---------------------------------------------------------------------------*/
 
+#if 0
 #define SUFFIX ".3danova"                 /* suffix for temporary data files */
+#else
+char SUFFIX[1024] = ".3danova." ;
+#endif
 
 #include "3dANOVA.h"
 #include "3dANOVA.lib"
@@ -84,7 +88,7 @@
    Routine to display 3dANOVA help menu.
 */
 
-void display_help_menu()
+void display_help_menu(int detail)
 {
   printf
     (
@@ -211,7 +215,7 @@ void display_help_menu()
 
   printf(ANOVA_FLOAT_HELP) ;
 
-  PRINT_COMPILE_DATE; exit(0);
+  PRINT_COMPILE_DATE; return;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -230,8 +234,6 @@ void get_options (int argc, char ** argv, anova_options * option_data)
   char message[MAX_NAME_LENGTH];            /* error message */
 
 
-  /*----- does user request help menu? -----*/
-  if (argc < 2 || strncmp(argv[1], "-help", 5) == 0)  display_help_menu();
 
   /*----- add to program log -----*/
   AFNI_logger (PROGRAM_NAME,argc,argv);
@@ -243,6 +245,12 @@ void get_options (int argc, char ** argv, anova_options * option_data)
   /*----- main loop over input options -----*/
   while (nopt < argc)
     {
+     /*----- does user request help menu? -----*/
+     if (strcmp(argv[nopt], "-help") == 0 ||
+         strcmp(argv[nopt], "-h") == 0)  {
+          display_help_menu(strlen(argv[nopt])>3?2:1);
+          exit(0);
+      }
 
       /*----- allocate memory for storing data file names -----*/
       if ((option_data->xname == NULL) && (option_data->a > 0))
@@ -551,9 +559,17 @@ void get_options (int argc, char ** argv, anova_options * option_data)
 
       /*----- unknown command -----*/
       sprintf (message,"Unrecognized command line option: %s\n", argv[nopt]);
-      ANOVA_error (message);
+      ERROR_message (message);
+      suggest_best_prog_option(argv[0], argv[nopt]);
+      exit(1);
     }
 
+  if (argc < 2)  {
+   ERROR_message("Too few options");
+   display_help_menu(0);
+   exit(1);
+  }
+
     if (option_data->old_method == 1)
       ANOVA_error("-old_method is insufficient by itself");
 }
@@ -1680,7 +1696,7 @@ void create_bucket (anova_options * option_data)
 
 
   /*----- begin command line for program 3drefit -----*/
-  strcpy (refit_str, "3drefit ");
+  strcpy (refit_str, "3drefit -addFDR ");
   ibrick = -1;
 
 
@@ -1691,12 +1707,12 @@ void create_bucket (anova_options * option_data)
 
       ibrick++;
       sprintf (str, " -sublabel %d %s:Inten ",
-	       ibrick, option_data->ftrname);
+	       ibrick, label_from_filename(option_data->ftrname));
       strcat (refit_str, str);
 
       ibrick++;
       sprintf (str, " -sublabel %d %s:F-stat ",
-	       ibrick, option_data->ftrname);
+	       ibrick, label_from_filename(option_data->ftrname));
       strcat (refit_str, str);
     }
 
@@ -1709,12 +1725,12 @@ void create_bucket (anova_options * option_data)
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:Mean ",
-		 ibrick, option_data->amname[i]);
+		 ibrick, label_from_filename(option_data->amname[i]));
 	strcat (refit_str, str);
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:t-stat ",
-		 ibrick, option_data->amname[i]);
+		 ibrick, label_from_filename(option_data->amname[i]));
 	strcat (refit_str, str);
       }
 
@@ -1727,12 +1743,12 @@ void create_bucket (anova_options * option_data)
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:Diff ",
-		 ibrick, option_data->adname[i]);
+		 ibrick, label_from_filename(option_data->adname[i]));
 	strcat (refit_str, str);
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:t-stat ",
-		 ibrick, option_data->adname[i]);
+		 ibrick, label_from_filename(option_data->adname[i]));
 	strcat (refit_str, str);
       }
 
@@ -1745,12 +1761,12 @@ void create_bucket (anova_options * option_data)
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:Contr ",
-		 ibrick, option_data->acname[i]);
+		 ibrick, label_from_filename(option_data->acname[i]));
 	strcat (refit_str, str);
 
 	ibrick++;
 	sprintf (str, " -sublabel %d %s:t-stat ",
-		 ibrick, option_data->acname[i]);
+		 ibrick, label_from_filename(option_data->acname[i]));
 	strcat (refit_str, str);
       }
 
@@ -1869,6 +1885,7 @@ int main (int argc, char ** argv)
    printf ("\n");
 #endif
 
+   UNIQ_idcode_fill(SUFFIX+strlen(SUFFIX)) ;  /* 27 Apr 2012 */
 
    /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
 
