@@ -122,8 +122,8 @@ int main( int argc , char *argv[] )
 
    /*---- official startup ---*/
 
-   PRINT_VERSION("3dLocalstat"); mainENTRY("3dLocalstat main"); machdep();
-   AFNI_logger("3dLocalstat",argc,argv) ;
+   PRINT_VERSION("3dLocalBistat"); mainENTRY("3dLocalBistat main"); machdep();
+   AFNI_logger("3dLocalBistat",argc,argv) ;
 
    /*---- loop over options ----*/
 
