@@ -187,6 +187,12 @@ void Syntax(int detail)
     "      'master' dataset to start with.  If you want to further change\n"
     "      the voxel sizes (in mm), you can use 3drefit to alter such\n"
     "      parameters after the initial act of creation ab nihilo.\n"
+    "  *** You can combine 3dUndump with 3dcalc to create an all zero\n"
+    "      3D+time dataset from 'thin air', as in\n"
+    "        3dUndump -dimen 128 128 32 -prefix AllZero_A -datum float\n"
+    "        3dcalc -a AllZero_A+orig -b '1D: 100@' -expr 0 -prefix AllZero_B\n"
+    "      If you replace the '0' expression with 'gran(0,1)', you'd get a\n"
+    "      random 3D+time dataset, which might be useful for testing purposes.\n"
     "\n"
     "* By default, the output dataset is of type '-fim', unless the -master\n"
     "   dataset is an anat type. You can change the output type later using 3drefit.\n"
