@@ -6,13 +6,98 @@ static int verb = 1 ;
 # include <omp.h>
 #endif
 
+/*---------------------------------------------------------------------------*/
+
+void mri_invertcontrast_inplace( MRI_IMAGE *im , float uperc , byte *mask )
+{
+   byte *mmm=NULL ;
+   int nvox , nhist , ii ; float *hist=NULL , *imar , ucut ;
+
+   if( im == NULL || im->kind != MRI_float ) return ;
+        if( uperc <  90.0f ) uperc =  90.0f ;
+   else if( uperc > 100.0f ) uperc = 100.0f ;
+
+   mmm = mask ;
+   if( mmm == NULL ) mmm = mri_automask_image(im) ;
+
+   nvox = im->nvox ;
+   hist = (float *)malloc(sizeof(float)*nvox) ;
+   imar = MRI_FLOAT_PTR(im) ;
+   for( nhist=ii=0 ; ii < nvox ; ii++ ){ if( mmm[ii] ) hist[nhist++] = imar[ii]; }
+   if( nhist < 100 ){
+     if( mmm != mask ) free(mmm) ;
+     free(hist) ; return ;
+   }
+   qsort_float(nhist,hist) ;
+   ii = (int)rintf(nhist*uperc*0.01f) ; ucut = hist[ii] ; free(hist) ;
+   for( ii=0 ; ii < nvox ; ii++ ){
+     if(  mmm[ii]                    ) imar[ii] = ucut - imar[ii] ;
+     if( !mmm[ii] || imar[ii] < 0.0f ) imar[ii] = 0.0f ;
+   }
+   if( mmm != mask ) free(mmm) ;
+   return ;
+}
+
+/*---------------------------------------------------------------------------*/
+
+void mri_clipedges_inplace( MRI_IMAGE *qm , float uclip , float vclip )
+{
+   int ii,jj,kk , ip,jp,kp , im,jm,km , nx,ny,nz,nxy,nxyz , pp,qq , nclip ;
+   float *imar , *qmar ;
+
+   if( qm == NULL || qm->kind != MRI_float ) return ;
+
+   nx = qm->nx ; ny = qm->ny ; nz = qm->nz ; nxy = nx*ny ; nxyz = nxy*nz ;
+   qmar = MRI_FLOAT_PTR(qm) ;
+   imar = malloc(sizeof(float)*nxyz) ;
+
+#define ISEDGE(i,j,k) (imar[(i)+(j)*nx+(k)*nxy]==0.0f)
+
+   if( verb ) fprintf(stderr,"e") ;
+   do{
+     memcpy(imar,qmar,sizeof(float)*nxyz) ;
+     for( nclip=pp=0 ; pp < nxyz ; pp++ ){
+       if( imar[pp] < uclip ) continue ;
+       kk = pp / nxy ; ii = pp % nx ; jj = (pp-kk*nxy)/nx ;
+       kp = kk+1 ; if( kp >= nz ) kp = nz-1 ;
+       km = kk-1 ; if( km <  0  ) km = 0 ;
+       jp = jj+1 ; if( jp >= ny ) jp = ny-1 ;
+       jm = jj-1 ; if( jm <  0  ) jm = 0 ;
+       ip = ii+1 ; if( ip >= nx ) ip = nx-1 ;
+       im = ii-1 ; if( im <  0  ) im = 0 ;
+       if( ISEDGE(ip,jj,kk) + ISEDGE(im,jj,kk) +
+           ISEDGE(ii,jp,kk) + ISEDGE(ii,jm,kk) +
+           ISEDGE(ii,jj,kp) + ISEDGE(ii,jj,km)  > 2 ){
+         qmar[pp] = 0.0f ; nclip++ ;
+       }
+     }
+     for( pp=0 ; pp < nxyz ; pp++ ){
+       if( imar[pp] < vclip ) continue ;
+       kk = pp / nxy ; ii = pp % nx ; jj = (pp-kk*nxy)/nx ;
+       kp = kk+1 ; if( kp >= nz ) kp = nz-1 ;
+       km = kk-1 ; if( km <  0  ) km = 0 ;
+       jp = jj+1 ; if( jp >= ny ) jp = ny-1 ;
+       jm = jj-1 ; if( jm <  0  ) jm = 0 ;
+       ip = ii+1 ; if( ip >= nx ) ip = nx-1 ;
+       im = ii-1 ; if( im <  0  ) im = 0 ;
+       if( ISEDGE(ip,jj,kk) + ISEDGE(im,jj,kk) +
+           ISEDGE(ii,jp,kk) + ISEDGE(ii,jm,kk) +
+           ISEDGE(ii,jj,kp) + ISEDGE(ii,jj,km)  > 4 ){
+         qmar[pp] = 0.0f ; nclip++ ;
+       }
+     }
+   } while(nclip > 0) ;
+
+   free(imar) ; return ;
+}
+
 /*---------------------------------------------------------------------------*/
 #undef  SWAP
 #define SWAP(x,y) (temp=x,x=y,y=temp)
 #undef  SORT2
 #define SORT2(a,b) if(a>b) SWAP(a,b)
 
-/*----- fast median-of-7 -----*/
+/*----- fast median-of-7 [mangles input array] -----*/
 
 static INLINE float median7(float *p)
 {
@@ -474,6 +559,7 @@ ENTRY("mri_GMunifize") ;
 int main( int argc , char *argv[] )
 {
    int iarg , ct , do_GM=0 ;
+   int do_T2=0 ; float T2_uperc=98.5f ; byte *T2_mask=NULL ;
    char *prefix = "Unifized" ;
    char *sspref = NULL ;
    THD_3dim_dataset *inset=NULL , *outset=NULL ;
@@ -497,7 +583,8 @@ int main( int argc , char *argv[] )
             "  #0 will be processed!\n"
             "* Method: Obi-Wan's personal variant of Ziad's sneaky trick.\n"
             "  (If you want to know what his trick is, you'll have to ask him, or\n"
-            "   read Obi-Wan's source code, which is a world of ecstasy and exaltation.)\n"
+            "   read Obi-Wan's source code, which is a world of ecstasy and exaltation,\n"
+            "   or just read all the way to the end of this help output.)\n"
             "* The principal motive for this program is for use in an image\n"
             "  registration script, and it may or may not be useful otherwise.\n"
             "\n"
@@ -506,6 +593,19 @@ int main( int argc , char *argv[] )
             "--------\n"
             "  -prefix pp = Use 'pp' for prefix of output dataset.\n"
             "  -input dd  = Alternative way to specify input dataset.\n"
+            "  -T2        = Treat the input as if it were T2-weighted, rather than\n"
+            "               T1-weighted. This processing is done simply by inverting\n"
+            "               the image contrast, processing it as if that result were\n"
+            "               T1-weighted, and then re-inverting the results.\n"
+            "              ++ This option is NOT guaranteed to be useful for anything!\n"
+            "              ++ Of course, nothing in AFNI comes with a guarantee :-)\n"
+            "              ++ If you want to be REALLY sneaky, giving this option twice\n"
+            "                 will skip the second inversion step, so the result will\n"
+            "                 look like a T1-weighted volume (except at the edges and\n"
+            "                 near blood vessels).\n"
+            "              ++ Might be useful for skull-stripping T2-weighted datasets.\n"
+            "              ++ Don't try the '-T2 -T2' trick on FLAIR-T2-weighted datasets.\n"
+            "                 The results aren't pretty!\n"
             "  -GM        = Also scale to unifize 'gray matter' = lower intensity voxels\n"
             "               (to aid in registering images from different scanners).\n"
             "              ++ This option is recommended for use with 3dQwarp when\n"
@@ -520,6 +620,12 @@ int main( int argc , char *argv[] )
             "               ++ Default value is %.1f, and should be changed proportionally\n"
             "                  if the dataset voxel size differs significantly from 1 mm.\n"
             "  -ssave ss  = Save the scale factor used at each voxel into a dataset 'ss'.\n"
+            "               ++ This is the white matter scale factor, and does not include\n"
+            "                  the factor from the '-GM' option (if that was included).\n"
+            "               ++ The input dataset is multiplied by the '-ssave' image\n"
+            "                  (voxel-wise) to get the WM-unifized image.\n"
+            "               ++ Another volume (with the same grid dimensions) could be\n"
+            "                  scaled the same way using 3dcalc, if that is needed.\n"
             "  -quiet     = Don't print the fun fun fun progress messages (but whyyyy?).\n"
             "               ++ For the curious, the codes used are:\n"
             "                   A = Automask\n"
@@ -527,7 +633,12 @@ int main( int argc , char *argv[] )
             "                   V = Voxel-wise histograms to get local scale factors\n"
             "                   U = duplo Up (convert local scale factors to full-size volume)\n"
             "                   W = multiply by White matter factors\n"
-            "                   G = multiply by Gray matter factors [optional]\n"
+            "                   G = multiply by Gray matter factors [cf the -GM option]\n"
+            "                   I = contrast inversion              [cf the -T2 option]\n"
+            "               ++ 'Duplo down' means to scale the input volume to be half the\n"
+            "                  grid size in each direction for speed when computing the\n"
+            "                  voxel-wise histograms.  The sub-sampling is done using the\n"
+            "                  median of the central voxel value and its 6 nearest neighbors.\n"
             "\n"
             "------------------------------------------\n"
             "Special options for Jedi AFNI Masters ONLY:\n"
@@ -538,6 +649,13 @@ int main( int argc , char *argv[] )
             "                 b = bottom percentile of normalizing data range [default=%.1f]\n"
             "                 r = top percentile of normalizing data range    [default=%.1f]\n"
             "\n"
+            "  -T2up uu   = Set the upper percentile point used for T2-T1 inversion.\n"
+            "               The default value is 98.5 (for no good reason), and 'uu' is\n"
+            "               allowed to be anything between 90 and 100 (inclusive).\n"
+            "               ++ The histogram of the data is built, and the uu-th percentile\n"
+            "                  point value is called 'U'. The contrast inversion is simply\n"
+            "                  given by output_value = max( 0 , U - input_value ).\n"
+            "\n"
             "  -clfrac cc = Set the automask 'clip level fraction' to 'cc', which\n"
             "               must be a number between 0.1 and 0.9.\n"
             "               A small 'cc' means to make the initial threshold\n"
@@ -554,6 +672,72 @@ int main( int argc , char *argv[] )
             "-- This code uses OpenMP to speed up the slowest part (voxel-wise histograms).\n"
 #endif
             , Uprad , Uprad , Upbot , Uptop ) ;
+
+     printf("\n"
+      "----------------------------------------------------------------------------\n"
+      "HOW IT WORKS (Ziad's sneaky trick is revealed at last! And more.)\n"
+      "----------------------------------------------------------------------------\n"
+      "The basic idea is that white matter in T1-weighted images is reasonably\n"
+      "uniform in intensity, at least when averaged over 'large-ish' regions.\n"
+      "\n"
+      "The first step is to create a local white matter intensity volume.\n"
+      "Around each voxel (inside the volume 'automask'), the ball of values\n"
+      "within a fixed radius (default=18.3 voxels) is extracted and these\n"
+      "numbers are sorted.  The values in the high-intensity range of the\n"
+      "histogram (default=70%% to 80%%) are averaged.  The result from this\n"
+      "step is a smooth 3D map of the 'white matter intensity' (WMI).\n"
+      "\n"
+      " [The parameters of the above process can be altered with the '-rbt' option.]\n"
+      " [For speed, the WMI map is produced on an image that is half-size in all   ]\n"
+      " [directions ('Duplo down'), and then is expanded back to the full-size     ]\n"
+      " [volume ('Duplo up').  The automask procedure can be somewhat controlled   ]\n"
+      " [via the '-clfrac' option.  The default setting is designed to deal with   ]\n"
+      " [heavily shaded images, where the WMI varies by a factor of 5 or more over ]\n"
+      " [the image volume.                                                         ]\n"
+      "\n"
+      "The second step is to scale the value at every voxel location x in the input\n"
+      "volume by the factor 1000/WMI(x), so that the 'white matter intensity' is\n"
+      "now uniform-ized to be 1000 everywhere.  (This is Ziad's 'trick'; it is easy,\n"
+      "works well, and doesn't require fitting some spatial model to the data: the\n"
+      "data provides its own model.)\n"
+      "\n"
+      "If the '-GM' option is used, then this scaled volume is further processed\n"
+      "to make the lower intensity values (presumably gray matter) have a contrast\n"
+      "similar to that from a collection of 3 Tesla MP-RAGE images that were\n"
+      "acquired at the NIH.  (This procedure is not Ziad's fault, and should be\n"
+      "blamed on the reclusive Obi-Wan Unifobi.)\n"
+      "\n"
+      "From the WM-uniform-ized volume, the median of all values larger than 1000\n"
+      "is computed; call this value P.  P-1000 represents the upward dispersion\n"
+      "of the high-intensity (white matter) voxels in the volume.  This value is\n"
+      "'reflected' below 1000 to Q = 1000 - 2*(P-1000), and Q is taken to be the\n"
+      "upper bound for gray matter voxel intensities.  A lower bound for gray\n"
+      "matter voxel values is estimated via the 'clip fraction' algorithm as\n"
+      "implemented in program 3dClipLevel; call this lower bound R.  The median\n"
+      "of all values between R and Q is computed; call this value G, which is taken\n"
+      "to be a 'typical' gray matter voxel instensity.  Then the values z in the\n"
+      "entire volume are linearly scaled by the formula\n"
+      "   z_out = (1000-666)/(1000-G) * (z_in-1000) + 1000\n"
+      "so that the WM uniform-ized intensity of 1000 remains at 1000, and the gray\n"
+      "matter median intensity of G is mapped to 666.  (Values z_out that end up\n"
+      "negative are set to 0; as a result, some of CSF might end up as 0.)\n"
+      "The value 666 was chosen because it gave results visually comparable to\n"
+      "various NIH-generated 3 Tesla T1-weighted datasets.  (Any suggestions that\n"
+      "this value was chosen for other reasons will be treated as 'beastly'.)\n"
+      "\n"
+      "To recap: the WM uniform-ization process provides a linear scaling factor\n"
+      "that varies for each voxel ('local'), while the GM normalization process\n"
+      "uses a global linear scaling.  The GM process is optional, and is simply\n"
+      "designed to make the various T1-weighted images look similar.\n"
+      "\n"
+      "-----** CAVEAT **-----\n"
+      "This procedure was primarily developed to aid in 3D registration, especially\n"
+      "when using 3dQwarp, so that the registration algorithms are trying to match\n"
+      "images that are alike.  It is *NOT* intended to be used for quantification\n"
+      "purposes, such as Voxel Based Morphometry!  That would better be done via\n"
+      "the 3dSeg program, which is far more complicated.\n"
+      "----------------------------------------------------------------------------\n"
+     ) ;
      PRINT_COMPILE_DATE ; exit(0) ;
    }
 
@@ -564,6 +748,7 @@ int main( int argc , char *argv[] )
    /*-- scan command line --*/
 
    THD_automask_set_clipfrac(0.1f) ;  /* 22 May 2013 */
+   THD_automask_extclip(1) ;          /* 19 Dec 2014 */
 
    iarg = 1 ;
    while( iarg < argc && argv[iarg][0] == '-' ){
@@ -623,6 +808,17 @@ int main( int argc , char *argv[] )
        do_GM++ ; iarg++ ; continue ;
      }
 
+     if( strcasecmp(argv[iarg],"-T2") == 0 ){  /* 18 Dec 2014 */
+       do_T2++ ; iarg++ ; continue ;
+     }
+
+     if( strcasecmp(argv[iarg],"-T2up") == 0 ){  /* 18 Dec 2014 */
+       T2_uperc = (float)strtod( argv[++iarg] , NULL ) ;
+       if( T2_uperc < 90.0f || T2_uperc > 100.0f )
+         ERROR_exit("-T2up value is out of range 90..100 :-(") ;
+       iarg++ ; continue ;
+     }
+
      if( strcasecmp(argv[iarg],"-quiet") == 0 ){
        verb = 0 ; iarg++ ; continue ;
      }
@@ -654,6 +850,14 @@ int main( int argc , char *argv[] )
    imin = mri_to_float( DSET_BRICK(inset,0) ) ; DSET_unload(inset) ;
    if( imin == NULL ) ERROR_exit("Can't copy input dataset brick?!") ;
 
+   /* invert T2? */
+
+   if( do_T2 ){
+     if( verb ) fprintf(stderr,"I") ;
+     T2_mask = mri_automask_image(imin) ;
+     mri_invertcontrast_inplace( imin , T2_uperc , T2_mask ) ;
+   }
+
    /* do the actual work */
 
    imout = mri_WMunifize(imin) ;          /* local WM scaling */
@@ -680,6 +884,13 @@ int main( int argc , char *argv[] )
 
    if( do_GM ) mri_GMunifize(imout) ;     /* global GM scaling */
 
+   if( do_T2 == 1 ){          /* re-invert T2? */
+     if( verb ) fprintf(stderr,"I") ;
+     mri_invertcontrast_inplace( imout , T2_uperc , T2_mask ) ;
+   } else if( do_T2 == 2 ){   /* don't re-invert, but clip off bright edges */
+     mri_clipedges_inplace( imout , PKVAL*1.111f , PKVAL*1.055f ) ;
+   }
+
    if( verb ) fprintf(stderr,"\n") ;
 
    /* create output dataset, and write it into the historical record */
