@@ -219,16 +219,18 @@ int main( int argc , char * argv[] )
   "                                                                        \n"
   "* -quiet      => Suppress all non-essential output                      \n"
   "                                                                        \n"
-  "* -mni        => If the input dataset is in +tlrc coordinates, this     \n"
-  "                 option will stretch the output xyz-coordinates to the  \n"
-  "                 MNI template brain.                                    \n"
+  "* -mni        => If the input dataset has the +tlrc view, this option   \n"
+  "                 will transform the output xyz-coordinates from TLRC to \n"
+  "                 MNI space.\n"
   "                                                                        \n"
+  "           N.B.0: Only use this option if the dataset is in Talairach   \n"
+  "                  space, NOT when it is already in MNI space.           \n"
   "           N.B.1: The MNI template brain is about 5 mm higher (in S),   \n"
   "                  10 mm lower (in I), 5 mm longer (in PA), and tilted   \n"
   "                  about 3 degrees backwards, relative to the Talairach- \n"
   "                  Tournoux Atlas brain.  For more details, see          \n"
   "                    http://www.mrc-cbu.cam.ac.uk/Imaging/mnispace.html  \n"
-  "           N.B.2: If the input dataset is not in +tlrc coordinates,     \n"
+  "           N.B.2: If the input dataset does not have the +tlrc view,    \n"
   "                  then the only effect is to flip the output coordinates\n"
   "                  to the 'LPI' (neuroscience) orientation, as if you    \n"
   "                  gave the '-orient LPI' option.)                       \n"
