@@ -8,16 +8,13 @@ print("Website: http://afni.nimh.nih.gov/sscc/gangc/SVAR.html")
 print("SSCC/NIMH, National Institutes of Health, Bethesda MD 20892")
 print("#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++")
 
-libLoad <- function(myLib) {
-   sucLoad <- FALSE
-   sucCheck <- FALSE
-   try(sucLoad <- library(myLib, character.only = TRUE, logical.return = TRUE))
-   if (sucLoad) {print(sprintf("Package %s successfully loaded!", myLib)); sucCheck <- TRUE} else {
-	  	try(install.packages(myLib))
-      try(sucLoad <- library(myLib, character.only = TRUE, logical.return = TRUE))
-      if (sucLoad) print(sprintf("Package %s successfully loaded...", myLib)) 
-   	}
+first.in.path <- function(file) {
+   ff <- paste(strsplit(Sys.getenv('PATH'),':')[[1]],'/', file, sep='')
+   ff<-ff[lapply(ff,file.exists)==TRUE];
+   #cat('Using ', ff[1],'\n');
+   return(gsub('//','/',ff[1], fixed=TRUE))
 }
+source(first.in.path('AFNIio.R'))
 
 # header assumed for multi-column files, but not for one-column ones
 # readMultiFiles <- function(nFiles, dim, inData) { 
@@ -377,8 +374,8 @@ rma <- function(yi, vi, mods=NULL, method="REML", addint=TRUE, ci=95, digits=4,
 
 
 
-libLoad("network")  # network drawing
 #libLoad('tcltk')    # for graphics
+pkgLoad('network')
 
 print("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~")
 print("Visit http://afni.nimh.nih.gov/sscc/gangc/SVAR.html and makse sure")
@@ -398,8 +395,9 @@ print("Use CNTL-C on Unix or ESC on GUI version of R to stop at any moment.")
 anaType <- as.integer(readline("Analysis type (0: quit; 1: individual; 2: group)? "))
 
 if (anaType==1) {
-libLoad("gsl")      # Legendre polynomials
-libLoad("vars")     # VAR modeling 
+#libLoad("gsl")      # Legendre polynomials
+#libLoad("vars")     # VAR modeling 
+pkgLoad(c('gsl', 'vars'))
 
 anotherAna <- 1
 while (anotherAna==1) {
