@@ -16,19 +16,37 @@ static void vstep_print(void)
    vn++ ;
 }
 
+/* If a label ends with '*', return 
+the length of the string -1. That would be the 
+number of characters to match. 
+Otherwise, return -1 */
+int SUMA_is_wild_hspec_label(char *lab) 
+{
+   static char FuncName[]={"SUMA_is_wild_hspec_label"};
+   int nlab = 0;
+
+   SUMA_ENTRY;
+
+   if (!lab) SUMA_RETURN(-1);
+   nlab = strlen(lab);
+   if (lab[nlab-1] == '*') SUMA_RETURN(nlab-1);
+
+   SUMA_RETURN(-1);
+}
+
 static HELP_OPT GenFeatureDistOptList[] = {
    {  
 "-classes", 
 "-classes 'CLASS_STRING': CLASS_STRING is a semicolon delimited\n"
 "                         string of class labels. For example\n"
-"                         -classes 'CSF; WM; GM'", 
+"                         -classes 'CSF; WM; GM'\n", 
 NULL
       },
    {  
 "-features", 
 "-features 'FEATURES_STRING': FEATURES_STRING is a semicolon delimited\n"
 "                         string of features. For example\n"
-"                         -features 'MEAN.00_mm; median.19_mm; ...'", 
+"                         -features 'MEAN.00_mm; median.19_mm; ...'\n", 
 NULL
       },
    {  
@@ -36,7 +54,16 @@ NULL
 "-sig 'FEATURE_VOL1 FEATURE_VOL2 ...': Specify volumes that define\n"
 "                         the features. Each sub-brick is a feature\n"
 "                         and the sub-brick's name is used to name the \n"
-"                         feature. Multiple volumes get catenated", 
+"                         feature. Multiple volumes get catenated.\n"
+"                         Each occurence of -sig option must be paired with\n"
+"                         a -samp option. Think of each pair of '-sig, -samp'\n"
+"                         options as describing data on the same voxel grid; \n"
+"                         Think from the same subject. When specifying \n"
+"                         training data from K subjects, you will end up using\n"
+"                         K pairs of '-sig, -samp'.\n"
+"                         All volumes from the kth -sig instance should have \n"
+"                         the same voxel grid as each other and as that of\n"
+"                         the kth -samp datasets.\n",
 NULL
       },
    {  
@@ -46,17 +73,41 @@ NULL
 "                         should contain voxel values (keys) that are\n"
 "                         defined in -labeltable. You can specify multiple\n"
 "                         volumes, they all get catenated. Any volume can\n"
-"                         contain voxels from 1 or more classes.", 
+"                         contain voxels from 1 or more classes.\n"
+"                         Each occurence of -samp option must be paired with\n"
+"                         a -sig option. Think of each pair of '-sig, -samp'\n"
+"                         options as describing data on the same voxel grid; \n"
+"                         Think from the same subject. When specifying \n"
+"                         training data from K subjects, you will end up using\n"
+"                         K pairs of '-sig, -samp'.\n"
+"                         All volumes from the kth -samp instance should have \n"
+"                         the same voxel grid as each other and as that of\n"
+"                         the kth -sig datasets.\n",
 NULL
       },
+
+   {  
+"-hspec",
+"-hspec FEATURE MIN MAX NBINS: Set histogram parameters for feature FEATURE\n"
+"                              FEATURE: String label of feature\n"
+"                              MIN, MAX: Range of histogram\n"
+"                              NBINS: Number of bins\n"
+"        Use this option to set the histogram parameters for the features for\n"
+"        the automatic parameter selection was lousy. You can specify \n"
+"        for multiple features by using multiple -hspec instances. The only\n"
+"        condition is that all feature labels (FEATURE) must be part of the \n"
+"        set named in -features.\n" , 
+NULL 
+      },
+
    
    {  
 "-prefix",
 "-prefix PREF: PREF is the prefix for all output volume that are not \n"
-"              debugging related.", 
+"              debugging related.\n", 
 "GenFeatDist" 
       },
-
+   
    {  
 "-ShowTheseHists",
 "-ShowTheseHists HISTNAMES: Show histograms specified by HISTNAMES and quit.\n"
@@ -68,18 +119,18 @@ NULL
    {  
 "-overwrite",
 "-overwrite: An option common to almost all AFNI programs. It is \n"
-"            automatically turned on if you provide no PREF.",
+"            automatically turned on if you provide no PREF.\n",
 NULL
       },
    {  
 "-debug",
-"-debug: Debugging level",
+"-debug: Debugging level\n",
 "1"
       },
 
    {  
 "-labeltable",
-"-labeltable LT: Specify the label table",
+"-labeltable LT: Specify the label table\n",
 "1"
       },
    {  NULL, NULL, NULL  }
@@ -226,7 +277,7 @@ SEG_OPTS *GenFeatureDist_Default(char *argv[], int argc)
 int GenFeatureDist_CheckOpts(SEG_OPTS *Opt) 
 {
    static char FuncName[]={"GenFeatureDist_CheckOpts"};
-   int i=0;
+   int i=0, kk=0, nmatch;
    
    SUMA_ENTRY;
    
@@ -252,7 +303,6 @@ int GenFeatureDist_CheckOpts(SEG_OPTS *Opt)
    if (Opt->labeltable_name) {
       Dtable *vl_dtable=NULL;
       char *labeltable_str=NULL;
-      int kk=0;
       
       /* read the table */
       if (!(labeltable_str = AFNI_suck_file( Opt->labeltable_name))) {
@@ -286,6 +336,26 @@ int GenFeatureDist_CheckOpts(SEG_OPTS *Opt)
       destroy_Dtable(vl_dtable); vl_dtable=NULL;
    } 
    
+   
+   /* Make sure any histogram specs are for a class in use */
+   for (kk=0; kk<Opt->N_hspec; ++kk) {
+      if ( (nmatch = SUMA_is_wild_hspec_label(Opt->hspec[kk]->label)) >= 0) {
+         if (!nmatch) break;
+         for (i=0; i<Opt->feats->num; ++i) {
+            if (!strncmp(Opt->feats->str[i], 
+                         Opt->hspec[kk]->label, nmatch)) break;
+         }
+      } else {
+         for (i=0; i<Opt->feats->num; ++i) {
+            if (!strcmp(Opt->feats->str[i], Opt->hspec[kk]->label)) break;
+         }
+      }
+      if (i==Opt->feats->num) {
+         SUMA_S_Warn("Feature %s in -hspec not found under -features and will have no impact on the output\n",
+                    Opt->hspec[kk]->label);
+      }
+   }
+   
    if (!Opt->keys) {
       /* add default keys */
       if (Opt->debug) SUMA_S_Note("Keys not available, assuming defaults");
@@ -484,6 +554,23 @@ SEG_OPTS *GenFeatureDist_ParseInput (SEG_OPTS *Opt, char *argv[], int argc)
          brk = 1;
 		}
       
+      if (!brk && (strcmp(argv[kar], "-hspec") == 0)) {
+         kar ++;
+			if (kar+3 >= argc)  {
+		  		fprintf (stderr, "need 4 arguments after -hspec \n");
+				exit (1);
+			}
+			Opt->hspec = (SUMA_HIST **)
+                  SUMA_realloc(Opt->hspec, (Opt->N_hspec+1)*sizeof(SUMA_HIST *));
+         Opt->hspec[Opt->N_hspec] = (SUMA_HIST*)SUMA_calloc(1,sizeof(SUMA_HIST));
+         Opt->hspec[Opt->N_hspec]->label = SUMA_copy_string(argv[kar++]);
+         Opt->hspec[Opt->N_hspec]->min = (float)strtod(argv[kar++],NULL);
+         Opt->hspec[Opt->N_hspec]->max = (float)strtod(argv[kar++],NULL);
+         Opt->hspec[Opt->N_hspec]->K   = (float)strtod(argv[kar],NULL);
+         ++Opt->N_hspec;
+         brk = 1;
+		}
+      
       
                   
       if (!brk && (strcmp(argv[kar], "-prefix") == 0)) {
@@ -596,8 +683,8 @@ SEG_OPTS *GenFeatureDist_ParseInput (SEG_OPTS *Opt, char *argv[], int argc)
 		}  
           
       if (!brk) {
-			fprintf (stderr,"Option %s not understood. \n"
-                         "Try -help for usage\n", argv[kar]);
+			fprintf (stderr,"Option #%d %s not understood. \n"
+                         "Try -help for usage\n", kar, argv[kar]);
 			suggest_best_prog_option(argv[0], argv[kar]);
          exit (1);
 		} else {	
@@ -624,7 +711,7 @@ int main(int argc, char **argv)
 {
    static char FuncName[]={"3dGenFeatureDist"};
    SEG_OPTS *Opt=NULL;
-   char *atr=NULL, sbuf[512];
+   char *atr=NULL, sbuf[512], *methods=NULL;
    int  cc, /* class counter */
         kk, /* key counter */
         aa, /* feature counter */
@@ -632,11 +719,13 @@ int main(int argc, char **argv)
         vv, /* voxel index */
         ss, /* subjects counter */
         iii, /* dummy counter */
+        nbins, /* number of bins */
         *ifeat=NULL, key, 
         **N_alloc_FCset=NULL, /* Number of values allocated for each 
                                  vector in FCset */
         **N_FCset=NULL, /* Number of filled values for each vector in FCset */ 
-        N_ffalloc=0, N_ff, isneg=0;
+        N_ffalloc=0, N_ff, isneg=0,
+        missfeatwarn=-1 /* Missing feature warning for some subject */;
    float fsf=0.0, fsb=0.0, 
          ***FCset=NULL, /* Table holding samples for each feature/class combo */ 
          hrange[2]={-3.0, 3.0}, bwidth1=0.05, bwidth=0.0,
@@ -710,7 +799,7 @@ int main(int argc, char **argv)
    /* For each feature, each class, collect the values */
    SUMA_S_Notev("Collecting data from %d subjects\n", Opt->sig_names->num);
    
-
+   missfeatwarn = -1;
    for (ss=0; ss<Opt->sig_names->num; ++ss) { /* for each subject */
       /* load the input data */   
       if (!(Opt->sig = Seg_load_dset( Opt->sig_names->str[ss] ))) {      
@@ -778,10 +867,20 @@ int main(int argc, char **argv)
          }
       }
       
-      SUMA_S_Notev("Loading sample classes for subject %d\n", ss);
+      SUMA_S_Notev("Loading sample classes for subject #%d\n", ss);
       if (!(Opt->samp = Seg_load_dset( Opt->samp_names->str[ss] ))) {      
          exit(1);
       }
+      
+      if (THD_dataset_mismatch(Opt->samp, Opt->sig)) {
+         SUMA_S_Err(
+            "Grid mismatch between -samp [%dx%dx%d] and \n"
+            "                      -sig  [%dx%dx%d] volumes for pair #%d\n", 
+            DSET_NX(Opt->samp), DSET_NY(Opt->samp), DSET_NZ(Opt->samp),
+            DSET_NX(Opt->sig), DSET_NY(Opt->sig), DSET_NZ(Opt->sig), ss);
+         exit(1);
+      }
+      
       if (Opt->debug > 1) {
          SUMA_S_Notev("Have %d sub-bricks in samples of dude %d\n", 
                      DSET_NVALS(Opt->samp), ss);
@@ -827,9 +926,11 @@ int main(int argc, char **argv)
                            if (masks[ss][vv]) masks[ss][vv] = 1; 
                         }
                      } else {
-                        SUMA_S_Warnv("Feature %s not found in subject %d\n",
+                        if (missfeatwarn != ss) {
+                           SUMA_S_Warnv("Feature %s not found in subject %d\n",
                                  Opt->feats->str[aa], ss);
-                        
+                           missfeatwarn = ss;
+                        }
                      }  
                   }
                }  
@@ -889,24 +990,66 @@ int main(int argc, char **argv)
           ff_s += SUMA_POW2(ff[iii]-ff_m);
       }
       ff_s = sqrt(ff_s/N_ff);
-      SUMA_S_Notev("Feature %s: mean %f, std %f\n", 
-                        Opt->feats->str[aa], ff_m, ff_s);
       sprintf(sbuf, "h(%s)",Opt->feats->str[aa]);
-      if ((float)isneg/(float)N_ff*100.0 > 1.0) {
-         hrange[0] =  ff_m-3*ff_s;
-         hrange[1] =  ff_m+3*ff_s;
-         bwidth = bwidth1*ff_s;
-      } else if (ff_m-3*ff_s > 0) {
-         hrange[0] =  ff_m-3*ff_s;
-         hrange[1] =  ff_m+3*ff_s;
-         bwidth = bwidth1*ff_s;
-      } else {
-         hrange[0] =  0;
-         hrange[1] =  6.0*ff_s/2.0;
-         bwidth = bwidth1*ff_s/2.0;
+      
+      /* Check if you have user specified binning specs */
+      bwidth = -1; nbins = -1;
+      for (iii=0; iii<Opt->N_hspec; ++iii) {
+         if (!strcmp(Opt->feats->str[aa], Opt->hspec[iii]->label)) {
+            hrange[0] =  Opt->hspec[iii]->min;
+            hrange[1] =  Opt->hspec[iii]->max;
+            nbins     =  Opt->hspec[iii]->K;
+            bwidth    = 0;
+            methods   =  "hands off sir";
+            break;
+         }
       }
-      if (!(hf[aa] = SUMA_hist_opt(ff, N_ff, 0, bwidth, hrange, sbuf, 1, 
-                                    0.1, "Range|OsciBinWidth"))) {
+      
+
+         
+      if (bwidth < 0) {
+         int nmatch = -1;
+         /* Check the wildcard option */
+         for (iii=0; iii<Opt->N_hspec; ++iii) {
+            if ((nmatch = SUMA_is_wild_hspec_label(Opt->hspec[iii]->label))>=0) {
+               if (!nmatch || !strncmp(Opt->feats->str[aa], 
+                                       Opt->hspec[iii]->label, nmatch)) {
+                  SUMA_S_Note("Feature %s matched with hspec %s\n",
+                              Opt->feats->str[aa], Opt->hspec[iii]->label);
+                  hrange[0] =  Opt->hspec[iii]->min;
+                  hrange[1] =  Opt->hspec[iii]->max;
+                  nbins     =  Opt->hspec[iii]->K;
+                  bwidth    = 0;
+                  methods   =  "hands woff sir";
+                  break;
+               }
+            }
+         }
+      }
+      
+      if (bwidth < 0) { /* no user specs found */
+         nbins = 0;
+         methods = "Range|OsciBinWidth";
+         if ((float)isneg/(float)N_ff*100.0 > 1.0) {
+            hrange[0] =  ff_m-3*ff_s;
+            hrange[1] =  ff_m+3*ff_s;
+            bwidth = bwidth1*ff_s;
+         } else if (ff_m-3*ff_s > 0) {
+            hrange[0] =  ff_m-3*ff_s;
+            hrange[1] =  ff_m+3*ff_s;
+            bwidth = bwidth1*ff_s;
+         } else {
+            hrange[0] =  0;
+            hrange[1] =  6.0*ff_s/2.0;
+            bwidth = bwidth1*ff_s/2.0;
+         }
+      }
+      SUMA_S_Notev("Feature %s: mean %f, std %f\n"
+                   "Hist params: [%f %f], binwidth %f\n", 
+                        Opt->feats->str[aa], ff_m, ff_s,
+                        hrange[0], hrange[1], bwidth);
+      if (!(hf[aa] = SUMA_hist_opt(ff, N_ff, nbins, bwidth, hrange, sbuf, 1, 
+                                    0.1, methods))) {
          SUMA_S_Errv("Failed to generate histogram for %s. \n"
                      "This will cause trouble at classification.\n",
                      Opt->feats->str[aa]);
@@ -948,7 +1091,7 @@ int main(int argc, char **argv)
          sprintf(sbuf, "h(%s|%s)",Opt->feats->str[aa], Opt->clss->str[cc]);
          hrange[0] = hf[aa]->min; hrange[1] = hf[aa]->max; 
          /* Do not optimize hist range and binwidth anymore, 
-            but allow smoothing. THis is needed when a particular 
+            but allow smoothing. This is needed when a particular 
             class has very few samples */
          if (!(hh[aa][cc] = SUMA_hist_opt(FCset[aa][cc], N_FCset[aa][cc], 
                                     hf[aa]->K, hf[aa]->W, 
@@ -1073,7 +1216,8 @@ int main(int argc, char **argv)
       masks[ss]=NULL;
    }
    
-   SUMA_S_Notev("Consider running this script to examine the distributions:\n"
+   SUMA_S_Notev("\n"
+                "Consider running this script to examine the distributions:\n"
                 "   @ExamineGenFeatDists -fdir %s -odir %s\n",
                 Opt->proot, Opt->proot);
    
