@@ -53,9 +53,12 @@ void usage_SUMA_SurfClust (int detail)
 "     -athresh tval: Apply absolute thresholding prior to clustering.\n"
 "                    A node n is considered if | thresh_col[n] | > tval.\n" 
 "     -amm2 minarea: Do not output results for clusters having\n"
-"                    an area less than minarea.\n"
+"                    an area less than minarea. \n"
+"                    If minarea < 0 AND -n is not set (or < 0)\n"
+"                    then minnodes = -minarea . See option -n below.\n"
 "     -n  minnodes: Do not output results for clusters having\n"
-"                    less nodes than minnodes.\n" 
+"                    less nodes than minnodes.\n"
+"                    minnodes can get set with negative minarea above.\n"
 "     -prefix OUTPREF: Prefix for output.\n"
 "                      Default is the prefix of \n"
 "                      the input dataset.\n"
