@@ -1,10 +1,10 @@
 #ifndef SUMA_DISPLAY_INCLUDED
 #define SUMA_DISPLAY_INCLUDED
-
+ 
 /* 
 
    Historical Note from Fri Jan  3 10:21:52 EST 2003:
-   the method for hiding a surface viewer (and other controllers), used to have     three options prior to Fri Jan  3 10:21:52 EST 2003
+   the method for hiding a surface viewer (and other controllers), used to have      three options prior to Fri Jan  3 10:21:52 EST 2003
    Now only SUMA_WITHDRAW and NOT SUMA_DESTROY should be used.
 
    As of Wed Sep 23 14:45:59 EDT 2009
@@ -15,7 +15,8 @@
    It appears that GLX implementation is full of uninitialzation errors, 
    according to Valgrind. 
    
-   So now one can choose between three closing modes. For widgets with GLX drawables (Viewers, and SurfaceControllers) use SUMA_UNREALIZE.
+   So now one can choose between three closing modes. For widgets with GLX
+   drawables (Viewers, and SurfaceControllers) use SUMA_UNREALIZE.
    For other, stick with SUMA_WITHDRAW as previously done.
 */
 
@@ -148,10 +149,9 @@ sets the select color of the widget to its foreground color */
 
 #define SUMA_SET_GL_PROJECTION(csv, ortho) {  \
    if (!ortho) { \
-      if (LocalHead) \
-         fprintf (SUMA_STDOUT,\
-                  "%s: Setting up matrix mode and perspective ...\n", \
-                  FuncName); \
+      SUMA_LH("Setting up matrix mode and perspective\n"\
+              "iState=%d, Apsect=%f, FOV=%p...\n",\
+              csv->iState, csv->Aspect, csv->FOV); \
       if (csv->FOV[csv->iState] < 0.00001) { \
          /* This can happen when only Non-SO objects are loaded
             Just do nothing  without fanfare */ \
@@ -170,10 +170,8 @@ sets the select color of the widget to its foreground color */
          csv->GVS[csv->StdView].ViewFrom[2];  \
       GLdouble m_szx = m_sz * csv->Aspect;   \
       GLdouble m_szy = m_sz ;   \
-      if (LocalHead) \
-         fprintf (SUMA_STDOUT,\
-                  "%s: Setting up matrix mode and orthographic projection "\
-                  "(m_szx = %g, m_szy=%g)...\n", FuncName, m_szx, m_szy); \
+      SUMA_LH("Setting up matrix mode and orthographic projection "\
+              "(m_szx = %g, m_szy=%g)...\n", m_szx, m_szy); \
       glMatrixMode (GL_PROJECTION); \
       glLoadIdentity ();   \
       glOrtho( -m_szx, m_szx, \
@@ -346,7 +344,8 @@ void SUMA_cb_closeViewerCont(Widget w, XtPointer data, XtPointer callData);
 void SUMA_cb_XHlock_toggled(Widget w, XtPointer data, XtPointer callData);
 void SUMA_cb_XHviewlock_toggled(Widget w, XtPointer data, XtPointer callData);
 void SUMA_cb_closeSurfaceCont(Widget w, XtPointer data, XtPointer callData);
-SUMA_Boolean SUMA_WriteCont_Help(SUMA_DO_Types do_type, int targ, char *fname);
+SUMA_Boolean SUMA_WriteCont_Help(SUMA_DO_Types do_type, TFORM targ, char *fname);
+SUMA_Boolean SUMA_Snap_AllCont(SUMA_DO_Types do_type, char *fname);
 void SUMA_cb_createSurfaceCont(Widget w, XtPointer data, XtPointer callData);
 void SUMA_cb_createSurfaceCont_SO(Widget w, XtPointer data, XtPointer callData);
 void SUMA_cb_createSurfaceCont_TDO(Widget w, XtPointer data, XtPointer callData);
@@ -477,7 +476,10 @@ void SUMA_ATF_SetValue (SUMA_ARROW_TEXT_FIELD * AF);
 void SUMA_ATF_cb_label_Modify (Widget w, XtPointer client_data, XtPointer call_data);
 void SUMA_leave_EV( Widget w , XtPointer client_data ,
                   XEvent * ev , Boolean * continue_to_dispatch );
-void SUMA_ATF_cb_label_Focus (Widget w, XtPointer client_data, XtPointer call_data);
+void SUMA_press_EV( Widget w , XtPointer client_data ,
+                    XEvent * ev , Boolean * continue_to_dispatch );
+void SUMA_ATF_cb_label_Focus (Widget w, XtPointer client_data, 
+                    XtPointer call_data);
 void SUMA_PositionWindowRelative (Widget New, Widget Ref, SUMA_WINDOW_POSITION Loc);
 void SUMA_cb_DrawROI_Finish (Widget w, XtPointer data, XtPointer client_data);
 void SUMA_cb_DrawROI_Join (Widget w, XtPointer data, XtPointer client_data);
@@ -545,6 +547,7 @@ void SUMA_PromptUnmap_cb (Widget w, XtPointer data, XtPointer calldata);
 void SUMA_FreePromptDialogStruct(SUMA_PROMPT_DIALOG_STRUCT *prmpt);
 void  SUMA_cb_ToggleManagementColPlaneWidget(Widget w, XtPointer data, 
                                                       XtPointer client_data);
+void SUMA_cb_AllConts(Widget w, XtPointer data, XtPointer client_data);
 void SUMA_cb_SurfCont_SwitchPage (void *data);
 void SUMA_cb_ColPlane_NewOrder (void *data);
 int SUMA_ColPlane_NewOrder     (SUMA_ALL_DO *ado, SUMA_OVERLAYS *colp,
@@ -837,6 +840,7 @@ SUMA_Boolean SUMA_ModifyTable(SUMA_TABLE_FIELD *TF, int Nrows);
 void SUMA_delete_mask_timeout_CB( XtPointer client_data , XtIntervalId * id);
 void SUMA_cb_Mask_Delete(Widget wcall, XtPointer cd1, XtPointer cbs);
 SUMA_Boolean SUMA_DeleteMask(char *ado_id);
+SUMA_Boolean SUMA_DeleteAllMasks(char *labeled, SUMA_DO *dov, int N_dov);
 SUMA_MaskDO * SUMA_findanyMDOp_inDOv(SUMA_DO *dov, int N_dov, int *dov_id);
 SUMA_MaskDO * SUMA_findanyMDOp(int *dov_id);
 DList *SUMA_AssembleMasksList(int withShadow);
@@ -875,6 +879,7 @@ SUMA_Boolean SUMA_LoadMultiMasks_eng (char *filename,
 void SUMA_LoadMultiMasks (char *filename, void *data);
 void SUMA_SaveMultiMasks (char *filename, void *data);
 SUMA_Boolean SUMA_SaveMultiMasks_eng (char *filename);
+SUMA_Boolean SUMA_wait_till_visible(Widget w, int maxms);
 
 /* 
    *************** Convolution utilities *************** 
@@ -939,19 +944,22 @@ SUMA_Boolean SUMA_Register_Widget_Children_Help(Widget, char *name,
 #define SUMA_DrawROI_ParentLabel_help  \
    "Label of the ROI's parent surface." 
 
-#define SUMA_DrawROI_DrawROIMode_help\
+#define SUMA_DrawROI_DrawROIMode_help \
    "Toggles ROI drawing mode.\n" \
    "If turned on, then drawing is enabled \n"   \
    "and the cursor changes to a target. \n"  \
    "To draw, use the right mouse button. \n" \
    "If you want to pick a node without causing \n" \
-   "a drawing action, use shift+right button."
+   "a drawing action, use shift+right button.\n\n"\
+   "After the draw ROI window is open, you can toggle \n"\
+   "this button via :ref:`ctrl+d<LC_Ctrl+d>` also."
    
-#define SUMA_DrawROI_ContROIMode_help\
+#define SUMA_DrawROI_ContROIMode_help \
    "Toggles ROI contour drawing \n" \
-   "If turned on, then contours are drawn around filled ROIs\n" 
+   "If turned on, then contours are drawn around filled ROIs.\n" \
+   "Contours will *float* over other displayed datasets\n" 
    
-#define SUMA_DrawROI_PenMode_help\
+#define SUMA_DrawROI_PenMode_help \
    "Toggles Pen drawing mode\n"\
    "If turned on, the cursor changes shape to a pen. \n" \
    "In the pen mode, drawing is done with button 1. \n"  \
@@ -962,19 +970,19 @@ SUMA_Boolean SUMA_Register_Widget_Children_Help(Widget, char *name,
    "To pick a node, use shift+left button. \n"  \
    "Pen mode only works when Draw Mode is enabled."
 
-#define SUMA_DrawROI_AfniLink_help\
-   "Toggles Afni Link for ROI drawing.\n" \
-   "If turned on, then ROIs drawn on the surface are\n" \
-   "sent to AFNI. \n"   \
-   "Surface ROIs that are sent to AFNI are turned\n"  \
-   "into volume ROIs (VOIs) on the fly and displayed \n" \
-   "in a functional volume with the same colormap used in SUMA.\n"   \
-   "The mapping from the surface domain (ROI) to the volume \n"   \
-   "domain (VOI) is done by intersection of the first with \n" \
-   "the latter. The volume used for the VOI has the same \n"   \
-   "resolution (grid) as the Surface Volume (-sv option) \n"   \
-   "used when launching SUMA. The color map used for ROIs \n"  \
-   "is set by the environment variable SUMA_ROIColorMap."
+   #define SUMA_DrawROI_AfniLink_help \
+"Toggles Afni Link for ROI drawing.\n" \
+"If turned on, then ROIs drawn on the surface are\n" \
+"sent to AFNI. \n"   \
+"Surface ROIs that are sent to AFNI are turned\n"  \
+"into volume ROIs (VOIs) on the fly and displayed \n" \
+"in a functional volume with the same colormap used in SUMA.\n"   \
+"The mapping from the surface domain (ROI) to the volume \n"   \
+"domain (VOI) is done by intersection of the first with \n" \
+"the latter. The volume used for the VOI has the same \n"   \
+"resolution (grid) as the Surface Volume (-sv option) \n"   \
+"used when launching SUMA. The color map used for ROIs \n"  \
+"is set by the environment variable :ref:`SUMA_ROIColorMap<SUMA_ROIColorMap>`."
    
 #define SUMA_DrawROI_Label_help  \
    "Label of ROI being drawn.\n" \
@@ -1034,82 +1042,90 @@ SUMA_Boolean SUMA_Register_Widget_Children_Help(Widget, char *name,
    
 #define SUMA_DrawROI_SaveFormat_help   \
    "File format for saving ROI:\n"  \
-   "Format options are 1D and NIML. \n"   \
-   "   The 1D format is the same one used in AFNI. \n"   \
+   "Format options are 1D and NIML.:LR:\n"   \
+   "   The 1D format is the same one used in AFNI.:LR:\n"   \
    "It is an ASCII file with 2 values per line. The first \n"  \
    "value is a node index, the second is the node's value. \n" \
    "Needless, to say, this format does not support the storage \n"   \
    "of ROI auxiliary information such as Label and \n"   \
    "Parent Surface, etc., nor does it preserve the order in which \n"   \
-   "nodes are traversed during a tracing. For that you'll have to use NIML.\n" \
-   "   NIML is a whole different story which will be documented \n"  \
+   "nodes are traversed during a tracing. "\
+   "For that you'll have to use :term:NIML.:LR:\n" \
+   ": :NIML is a whole different story which will be documented \n"  \
    "(if necessary) in the future. Suffice it to say that in NIML \n" \
    "format you can store all the auxiliary information about \n"  \
-   "each ROI, unlike with the .1D format. \n"   \
+   "each ROI, unlike with the .1D format.:LR:\n"   \
+   ":SPX:"\
+   "**But more importantly**, the NIML format allows you to preserve "  \
+   "the order in which you traced the ROI. You can actually use \n" \
+   ":ref:`Undo<ROICont->ROI->Undo>`/ref:`Undo<ROICont->ROI->Redo>` on "\
+   "ROIs save in NIML format."\
+   ":DEF:"\
    "But more importantly, the NIML format allows you to preserve\n"  \
    "--------------------  the order in which you traced the ROI. \n" \
+   ":SPX:"\
    "This information can be later used for the purpose of sampling \n"  \
    "cortical activity along a particular path. This would be accomplished \n" \
-   "with the aid of ROI2dataset's -nodelist* options, along with \n" \
-   "ConvertDset's -node_select_1D option."
+   "with the aid of ROI2dataset's -nodelist:SPX:\\:SPX:* options, along with \n"\
+   "ConvertDset's -node_select_1D option.:LR:\n"
    
 #define SUMA_DrawROI_SaveWhat_help  \
-   "Which ROIs to save?\n" \
+   "Which ROIs to save?:LR:\n" \
    "   This: saves the current ROI. \n"   \
    "   All: saves all ROIs on surfaces related to the Parent \n"  \
-   "        surface of the current ROI."
+   ":       :surface of the current ROI."
    
 #define SUMA_DrawROI_WhatDist_help  \
-   "Report length of drawn segments?\n" \
-   "   -----: No distance calculations. \n"   \
-   "   trace: Calculate distance along last\n"  \
-   "          traced segment.\n" \
-   "   all:   In addition to output from\n"  \
-   "          'trace', calculate the shortest\n"   \
-   "          distance between the first and \n"   \
-   "          last node of the trace.\n"  \
+   "Report length of drawn segments?:LR:\n" \
+   "   -----: No distance calculations.:LR:\n"   \
+   "   trace: Calculate distance along last \n"  \
+   ":        :traced segment.\n" \
+   "   all:   In addition to output from \n"  \
+   ":        :'trace', calculate the shortest \n"   \
+   ":        :distance between the first and \n"   \
+   ":        :last node of the trace.:LR:\n"  \
    "   The results are output to the Message Log \n"  \
-   "   window (Help --> Message Log) with the following\n" \
-   "   information:\n"  \
-   "   n0, n1: Indices of first and last node forming\n" \
-   "           the traced path.\n"  \
-   "   N_n:    Number of nodes forming the trace.\n"  \
-   "   lt:     Trace length calculated as the sum\n"  \
-   "           of the distances from node to node.\n"   \
-   "           This length is a slight overestimation\n"  \
-   "           of the geodesic length.\n" \
-   "           Units for all distances is the same as\n" \
-   "           the units for surface coordinates. Usually\n"   \
-   "           and hopefully in mm.\n" \
+   ": :window (Help --> Message Log) with the following\n" \
+   ": :information::LR:\n"  \
+   "   n0, n1: Indices of first and last node forming \n" \
+   ":         :the traced path.:LR:\n"  \
+   "   N_n:    Number of nodes forming the trace.:LR:\n"  \
+   "   lt:     Trace length calculated as the sum \n"  \
+   ":         :of the distances from node to node.\n"   \
+   ":         :This length is a slight overestimation \n"  \
+   ":         :of the geodesic length. \n" \
+   ":         :Units for all distances is the same as \n" \
+   ":         :the units for surface coordinates. Usually \n"   \
+   ":         :and hopefully in mm.:LR:\n" \
    "   lt_c:   Trace length corrected by a scaling factor\n"  \
-   "           from [1] to better approximate geodesic \n"  \
-   "           distances. Factor is 2/(1+sqrt(2)).\n" \
-   "           Do not use this factor when N_n is small. \n"\
-   "           Think of the extreme case when N_n is 2.\n"   \
+   ":         :from [1] to better approximate geodesic \n"  \
+   ":         :distances. Factor is 2/(1+sqrt(2)). \n" \
+   ":         :Do not use this factor when N_n is small. \n"\
+   ":         :Think of the extreme case when N_n is 2.:LR:\n"   \
    "   sd:     Shortest distance on the mesh (graph) \n" \
-   "           between n0 and n1 using Dijkstra's algorithm.\n"   \
-   "   sd_c:   Corrected shortest distance as for lt_c.\n"  \
+   ":         :between n0 and n1 using Dijkstra's algorithm.:LR:\n"   \
+   "   sd_c:   Corrected shortest distance as for lt_c.:LR:\n"  \
    "\n"  \
    "   Note 1: sd and sd_c take some time to compute. That is \n"  \
-   "           why they are only calculated when you select 'all'.\n"   \
-   "   Note 2: The output is formatted to be cut and pasted into\n"  \
-   "           a .1D file for ease of processing.\n"  \
-   "           You can include all the comment lines that\n"   \
-   "           start with '#'. But you cannot combine entries\n"  \
-   "           from the output obtained using 'all' option with \n" \
-   "           those from 'trace' since they produce different \n"  \
-   "           numbers of values.\n"  \
+   ":         :why they are only calculated when you select 'all'.:LR:\n"   \
+   "   Note 2: The output is formatted to be cut and pasted into \n"  \
+   ":         :a .1D file for ease of processing. \n"  \
+   ":         :You can include all the comment lines that \n"   \
+   ":         :start with '#'. But you cannot combine entries \n"  \
+   ":         :from the output obtained using 'all' option with \n" \
+   ":         :those from 'trace' since they produce different \n"  \
+   ":         :numbers of values.\n"  \
    "\n"  \
    "   [1] Fischl et al, Neuroimage 9, 195-207 1999, \n" \
-   "       Cortical Surface-Based Analysis."
+   ":     :Cortical Surface-Based Analysis."
    
 #define SUMA_DrawROI_Save_help \
    "Save the Drawn ROI to disk.\n"  \
    "Choose the file format and what is to be\n"   \
    "saved from the two menus ahead.\n"  \
-   "\n"  \
+   ":LR:\n"  \
    SUMA_DrawROI_SaveFormat_help  \
-   "\n"  \
+   ":LR:\n"  \
    SUMA_DrawROI_SaveWhat_help
 
 #define SUMA_closeDrawROI_help  \
@@ -1170,7 +1186,7 @@ SUMA_Boolean SUMA_Register_Widget_Children_Help(Widget, char *name,
    "viewer."
 
 #define SUMA_SurfCont_ColPlaneDim_hint \
-   "Dimming factor to apply to colormap." \
+   "Dimming factor to apply to colormap or color datasets." \
 
 #define SUMA_SurfCont_NodeRadGain_hint \
    "Gain factor to apply to node radius." \
@@ -1190,11 +1206,19 @@ SUMA_Boolean SUMA_Register_Widget_Children_Help(Widget, char *name,
 #define SUMA_SurfCont_ColPlaneOpacity_hint \
    "Opacity of Dset's colorplane." \
 
-#define SUMA_VR_help \
-   "Volume Rendering Settings.\n"
+   #define SUMA_VR_help \
+"Set the number of slices used to render the volume. "\
+"Volume rendering is done by slicing the volume from the far end along "\
+"your vieweing direction to the front, blending successive images along "\
+"the way. The more slices you use the better the result, something comparable "\
+"to the maximum number of voxels in any of the directions would be a good "\
+"start. Of course, the more slices, the slower the rendering.:LR:\n"\
+"Blending is affected by :ref:`Avl<VolCont->Dset_Controls->Avl>` and "\
+":ref:`Ath<VolCont->Dset_Controls->Ath>` settings."
+
 
 #define SUMA_VR_hint \
-   "VR params (use BHelp for details)"
+   "Volume Rendering Settings (use BHelp for details)"
 
 #define SUMA_SliceSelect_axial_help \
    "Select axial slice(s) to render.\n"\
