@@ -279,6 +279,9 @@ void SUMA_usage (SUMA_GENERIC_ARGV_PARSE *ps, int detail)
 "                                    number only\n"
 "   [-dev]: Allow access to options that are not well polished for\n"
 "           mass consuption.\n"   
+"   [-fake_cmap]: Use X11 to render cmap. This is only needed to get colorbar\n"
+"                 to appear when the frame is automatically captured by SUMA\n"
+"                 for making documentation. This option has no other use.\n"
 "   [-update_env] Performs the set operations detailed under -environment\n"
 "   [-default_env] Output hard coded default environment values, ignoring\n"
 "                  user settings.\n"
@@ -664,7 +667,7 @@ int main (int argc,char *argv[])
             SUMA_S_Err("Failed to open %s for writing", argv[kar]);
             exit(1);
           }
-          SUMA_help_message(fout,1);
+          SUMA_help_message(fout,SPX);
           fclose(fout); fout = NULL;
           exit (0);
 		}
@@ -675,7 +678,7 @@ int main (int argc,char *argv[])
             SUMA_S_Err("Failed to open Mouse_Keyboard_Controls.txt for writing");
             exit(1);
           }
-          SUMA_help_message(fout,0);
+          SUMA_help_message(fout,TXT);
           fclose(fout); fout = NULL;
           exit (0);
 		}
@@ -686,7 +689,7 @@ int main (int argc,char *argv[])
       }
       
       if (strcmp(argv[kar], "-environment") == 0) {
-			 s = SUMA_env_list_help (0, 0);
+			 s = SUMA_env_list_help (0, NO_FORMAT);
           fprintf (SUMA_STDOUT,  
             "#SUMA ENVIRONMENT \n"
             "# If you do not have a ~/.sumarc file, cannot find a SUMA\n"
@@ -709,7 +712,7 @@ int main (int argc,char *argv[])
 		}
       
       if (strcmp(argv[kar], "-default_env") == 0) {
-			 s = SUMA_env_list_help (1, 0);
+			 s = SUMA_env_list_help (1, NO_FORMAT);
           fprintf (SUMA_STDOUT,  
                   "#SUMA DEFAULT ENVIRONMENT (user settings ignored)\n"
                   "# see also suma -udate_env or suma -environment\n"
@@ -796,6 +799,13 @@ int main (int argc,char *argv[])
 			brk = YUP;
 		}
 		
+      if (!brk && (strcmp(argv[kar], "-fake_cmap") == 0)) {
+			SUMA_S_Warn("-fake_cmap is for automatic selfies of the widgets.\n"
+                     "You should not use this option for any other reason\n");
+			SUMAg_CF->Fake_Cmap = YUP;
+			brk = YUP;
+		}
+		
       if (!brk && SUMAg_CF->Dev && (strcmp(argv[kar], "-truth_table") == 0)) {
 		   kar ++;
 			if (kar >= argc)  {
