@@ -362,7 +362,6 @@ int main (int argc,char *argv[])
    int nbad;
    int too_close = 0, need_neighb_adjust = 0, need_more_adjustment = 0;
    static double energy, energy_sum, time_elapsed;
-   SUMA_SPHERE_QUALITY SSQ;
    SUMA_Boolean exists;
       
    MyCircle *Ci = NULL;
@@ -653,8 +652,7 @@ int main (int argc,char *argv[])
             for (i3=0; i3<3*SO->N_Node; ++i3) SO->NodeList[i3] = Ci->NewNodeList[i3];
             SUMA_RECOMPUTE_NORMALS(SO);
             shist = SUMA_HistString (NULL, argc, argv, NULL);
-            SSQ = SUMA_SphereQuality(SO, outfile_SphereQuality , shist);
-            nbad = SSQ.N_bad_facesets;
+            SUMA_SphereQuality(SO, outfile_SphereQuality , shist, NULL, &nbad);
             if(nbad && !first_bad_niter){ first_bad_niter = niter; }
             if (shist) SUMA_free(shist); shist = NULL;
             SUMA_Save_Surface_Object(SO_name, SO, SUMA_VEC, SUMA_ASCII, NULL);
@@ -762,8 +760,7 @@ int main (int argc,char *argv[])
       SUMA_RECOMPUTE_NORMALS(SO);
       shist = SUMA_HistString (NULL, argc, argv, NULL);
       fprintf( SUMA_STDERR, "\nNITER = %d", niter );
-      SSQ = SUMA_SphereQuality(SO, opt->outfile , shist);   
-      nbad = SSQ.N_bad_facesets;
+      SUMA_SphereQuality(SO, opt->outfile , shist, NULL, &nbad);   
       if (nbad) {
          fprintf(SUMA_STDERR,"Shist %s!:\n you have %d bad points!\n", FuncName, nbad);
       } else {
