@@ -49,6 +49,58 @@
 
 
 afni_history_struct dglen_history[] = {
+{ 18 , DEC, 2014 , DRG , "VmPFC atlas" , 
+    MINOR , TYPE_GENERAL, 
+    "Ventro-medial prefrontal cortex atlas",
+    "Worked with Scott Mackey to make maximum probability map atlas available"
+} ,
+{ 4 , DEC, 2014 , DRG , "@Align_Centers" , 
+    MINOR , TYPE_NEW_OPT, 
+    "1Dmat_only_nodset option",
+    "Undid former fix because other scripts may rely on these shifted datasets\n"
+    "and added new option. Datasets will not be output or modified with\n"
+    "new option, and just the transformation matrix is output"
+} ,
+
+{ 2 , DEC, 2014 , DRG , "@Align_Centers" , 
+    MICRO , TYPE_BUG_FIX, 
+    "fix for 1Dmat_only output",
+    "Datasets were output or modified even with this option,\n"
+    "Now just the transformation matrix is output"
+} ,
+
+{ 2 , DEC, 2014 , DRG , "align_epi_anat.py" , 
+    MINOR , TYPE_BUG_FIX, 
+    "fixes for child_anat and mean epi base",
+    "Thanks to Isaac Schwabacher for the child_anat fix!"
+} ,
+
+{ 9 , NOV, 2014 , DRG , "whereami connections" , 
+    MINOR , TYPE_MODIFY, 
+    "Web display includes connections links",
+    "Developed for macaque connection webpages"
+} ,
+{ 20 , OCT, 2014 , DRG , "Haskins Pediatric templates and atlases" , 
+    MAJOR , TYPE_GENERAL, 
+    "Nonlinear and affine versions of Haskins Pediatric templates and atlases",
+    "New templates with matching segmentation atlases are provided for\n"
+    "pediatric subjects, ages 8-12"
+} ,
+
+{ 17 , SEP, 2014 , DRG , "MNI nonlinear templates" , 
+    MINOR , TYPE_MODIFY, 
+    "Nonlinear version of MNI-152 template in distribution",
+    "The nonlinear 2009c version is more useful, particularly as a base for\n"
+    "nonlinear alignment. AFNI_atlas_spaces.niml includes descriptions for\n"
+    "native MNI152 2009c T1 template and a transformed version aligned to\n"
+    "the TT_N27 dataset in Talairach space"
+} ,
+
+{ 17 , SEP, 2014 , DRG , "auto_warp.py" , 
+    MICRO , TYPE_BUG_FIX, 
+    "Did not pass qw_opts properly to 3dQwarp"
+} ,
+
 { 4 , SEP, 2014 , DRG , "AFNI_ATLAS_PATH" , 
     MINOR , TYPE_NEW_ENV, 
     "Atlases and templates may be stored in location set by AFNI_ATLAS_PATH",
@@ -56,7 +108,7 @@ afni_history_struct dglen_history[] = {
     "This variable may hold multiple directories that specify the possible\n"
     "locations of atlases when the atlas definition does not include the\n"
     "path in the filename. The atlases are typically defined in \n"
-    "AFNI_atlas_spaces.niml file or in a CustomAtlases.niml file."
+    "AFNI_atlas_spaces.niml file or in a CustomAtlases.niml file"
 } ,
 
 { 9 , JUL, 2014 , DRG , "3dDWItoDT" , 
