@@ -66,8 +66,89 @@
 afni_history_struct ptaylor_history[] = {
 /*=====BELOW THIS LINE=====*/
 
+{ 21, Dec , 2014 , PT , "3dTrackID" , MINOR , TYPE_GENERAL,
+   "Change of string output in .niml.dset.",
+   "Make the label match the ROI string labels.\n"
+},
 
-   { 5, Aug , 2014 , PT , "3dTrackID" , MINOR , TYPE_MODIFY,
+{ 21, Dec , 2014 , PT , "3dNetCorr" , MINOR , TYPE_GENERAL,
+   "Output NIML dset automatically.",
+   "This allows users to view connectivity matrix info in SUMA easily.\n"
+},
+
+{ 21, Dec , 2014 , PT , "fat_mat_sel.py" , SUPER , TYPE_NEW_PROG,
+   "Plot, view and save matrix file info.",
+   "Works for both 3dNetCorr and 3dTrackID info.\n"
+},
+
+{ 15, Dec , 2014 , PT , "3dROIMaker" , MAJOR , TYPE_NEW_OPT,
+   "Make a subset of an ROI by choosing maximal neighoring values.",
+   "Start with peak value, add neighboring max until N voxels selected.\n"
+},
+
+{ 5, Nov , 2014 , PT , "3dROIMaker" , MAJOR , TYPE_NEW_ENV,
+   "Default neighborhoods now AFNI standard; labeltable functionality in.",
+   "Default 'hoods more standard, can still do other; labels by default.\n"
+},
+
+{ 5, Nov , 2014 , PT , "3dTrackID" , MINOR , TYPE_NEW_OPT,
+   "Switch to not output INDI and PAIR map files.",
+   "In connectome examples, this might save a lot of space.\n"
+},
+
+{ 24, Oct , 2014 , PT , "3dTrackID" , MINOR , TYPE_BUG_FIX,
+   "Fixed offset in track to volume coordinates ",
+   "Effect of bug restricted to viewing of tracts rather than volume masks "
+   "and connectivity matrices.\n"
+   "Offset was by half a voxel in each of the three dims.\n"
+},
+
+{ 26, Sep , 2014 , PT , "3dNetCorr" , MAJOR , TYPE_NEW_OPT,
+   "Allow labeltable reading and writing.",
+   "This allows users to use labeltables, and output labelled values everywhere.\n"
+},
+
+{ 26, Sep , 2014 , PT , "3dTrackID" , MAJOR , TYPE_NEW_OPT,
+   "Allow labeltable reading and writing.",
+   "This allows users to use labeltables, and output labelled values everywhere.\n"
+},
+
+{ 18, Sep , 2014 , PT , "fat_mvm_prep.py" , MICRO , TYPE_GENERAL,
+   "Change internal var/par names, and how helpfile is thrown.",
+   "More consistent naming, easier helpfile usage.\n"
+},
+
+{ 18, Sep , 2014 , PT , "fat_mvm_scripter.py" , MINOR , TYPE_NEW_OPT,
+   "Allow interaction terms in the user-defined statistical model.",
+   "Allow cat+quant or cat+cat variable interactions, and posthoc testing.\n"
+},
+
+{ 8, Sep , 2014 , PT , "fat_roi_row.py" , SUPER , TYPE_NEW_PROG,
+   "Select out one row of a matrix file, at user request.",
+   "Useful, for example, if wanting to view connectivity one-to-many.\n"
+},
+
+{ 8, Sep , 2014 , PT , "fat_mvm_prep.py" , SUPER , TYPE_NEW_PROG,
+   "Connect FATCAT with 3dMVM-- combine CSV and matrix data.",
+   "Build data table necessary for 3dMVM from MRI+other data.\n"
+},
+
+{ 8, Sep , 2014 , PT , "fat_mvm_scripter.py" , SUPER , TYPE_NEW_PROG,
+   "Connect FATCAT with 3dMVM-- write a basic command call to 3dMVM.",
+   "User specificies specific model, and awaaaay we go.\n"
+},
+
+{ 8, Sep , 2014 , PT , "fat_mvm_gridconv.py" , SUPER , TYPE_NEW_PROG,
+   "Connect FATCAT with 3dMVM-- modernize format of old *.grid files.",
+   "Prehistoric grid files had no labels. This updates them.\n"
+},
+
+{ 8, Sep , 2014 , PT , "3dROIMaker" , MINOR , TYPE_NEW_OPT,
+   "Allow pre-inflation of an input ROI, at user request.",
+   "Useful, for example, if wanting to go from WM->GM.\n"
+},
+
+{ 5, Aug , 2014 , PT , "3dTrackID" , MINOR , TYPE_MODIFY,
    "Less memory usage and a bit faster.",
    "More efficient internal handling of quantities.\n"
 },
