@@ -205,10 +205,16 @@ int ao_with_afniweb(char *fname)
                "http://afni.nimh.nih.gov/pub/dist/edu/"
                "data/CD/%s",fname);
             if ((s = ao_with_downloader(ww, 0))) {
-               fprintf(stderr,"Status %d on %s\n Search also failed under\n"
-                              "http://afni.nimh.nih.gov/pub/dist/tgz\n"
-                              "http://afni.nimh.nih.gov/pub/dist/edu/data/"
-                              , s, ww);
+               snprintf(ww,1023*sizeof(char),
+               "http://afni.nimh.nih.gov/pub/dist/"
+               "data/%s",fname);
+               if ((s = ao_with_downloader(ww, 0))) {
+                  fprintf(stderr,"Status %d on %s\n Search also failed under\n"
+                                 "http://afni.nimh.nih.gov/pub/dist/tgz\n"
+                                 "http://afni.nimh.nih.gov/pub/dist/edu/data/\n"
+                                 "http://afni.nimh.nih.gov/pub/dist/data/\n"
+                                 , s, ww);
+               }
             }
          }
       }   
@@ -404,7 +410,8 @@ void afni_open_usage(int detail)
 "\n"
 "Global Options:\n"
 "===============\n"
-"%s", 
+"%s\n%s", 
+   detail > 1 ? SUMA_Offset_SLines(get_help_help(),2):"",
    detail > 1 ? get_gopt_help():""); 
    PRINT_COMPILE_DATE ;
    }
@@ -435,7 +442,7 @@ int main(int argc, char **argv)
       "Global Options: options available to most AFNI programs, but usually\n"
       "                not found in the -help output.\n"
       "--------------------------------------------------------------------\n"
-             "%s", get_gopt_help());
+             "%s\n%s", SUMA_Offset_SLines(get_help_help(),3), get_gopt_help());
          return(0); 
       }      
       
@@ -451,12 +458,24 @@ int main(int argc, char **argv)
          continue; 
       }
       
+      if (strcmp(argv[iarg],"-b") == 0) { 
+         uprog = "browser";
+         ++iarg;
+         continue; 
+      }
+      
       if (strcmp(argv[iarg],"-d") == 0) { 
          uprog = "downloader"; 
          ++iarg;
          continue; 
       }
       
+      if (strcmp(argv[iarg],"-x") == 0) { 
+         uprog = "ExamineXmat"; 
+         ++iarg;
+         continue; 
+      }
+      
       if (strcmp(argv[iarg],"-r") == 0) { 
          uprog = "readme"; 
          ++iarg;
