@@ -13,6 +13,43 @@
 #define zischar(ch) ( ( ((ch) >= 'A' && (ch) <= 'Z' ) || ((ch) >= 'a' && (ch) <= 'z' ) ) ? 1 : 0 )
 #define isnakedarg(s) ( ( (s)[0] == '-' && strlen(s) > 1 && zischar((s)[1]) ) ? 0 : 1 )
 
+int count_procs(char *pname)
+{
+   char sbuf[1024]={""};
+   int nproc, jj;
+   FILE *fp=NULL;
+   int verb=0;
+   
+   if (!pname) pname = "apsearch";
+   
+   if (SUMA_isEnv("SUMA_CountProcs_Verb","YES")) verb = 1;
+   
+   if (verb) {
+      fprintf(stderr,"  Checking ps:\n");
+      sprintf(sbuf, "\\ps -caA | \\grep %s", pname);
+      system(sbuf);
+   }
+   
+   sprintf(sbuf, "afni_util.py -print \"get_process_depth(prog='%s')\"", pname);
+   if (verb) fprintf(stderr," Executing %s\n", sbuf);
+   
+   fp = popen( sbuf , "r" ) ;
+   if( fp == NULL ){ 
+      ERROR_message(" popen fails\n"); 
+      exit(1); 
+   }
+
+   jj = fscanf(fp,"%d",&nproc) ;
+   if( jj != 1 ){ 
+      ERROR_message(" 1st fscanf fails\n"); 
+      pclose(fp); 
+      exit(1); 
+   }
+   
+   pclose(fp); 
+   if (verb) fprintf(stderr,"Got %d\n", nproc);
+   return(nproc);
+}
 
 int update_help_for_afni_programs(int force_recreate, 
                                   byte verb, byte clean, 
@@ -110,15 +147,14 @@ int update_help_for_afni_programs(int force_recreate,
    RETURN(1);
 }
 
-
          
-void apsearch_usage(int detail) 
+int apsearch_usage(TFORM targ, int detail) 
 {
    int i = 0;
    
    ENTRY("apsearch_usage");
    /* print help message in three sections */
-   fprintf(stdout,
+   sphinx_fprintf(targ, stdout,
    "\n"
    "A program to perform simple approximate string searching. It's primary\n"
    "purpose is to test string matching for atlas area locations.\n"
@@ -127,7 +163,7 @@ void apsearch_usage(int detail)
    "           [OPTIONS]\n"
    "\n%s", detail ? "":"use -h or -help for more help detail.\n");
    if (detail) {
-      printf ( 
+      sphinx_printf (targ, 
 "Parameters:\n"
 "===========\n"
 "  -word WORD: WORD being sought\n"
@@ -141,6 +177,44 @@ void apsearch_usage(int detail)
 "  -popt PROG: Search for possible options of PROG that match WORD\n"
 "              Make sure you add the '-' to WORD if you are looking\n"
 "              for an actual option.\n"
+"  -raw_phelp PROG: Spit out the help string for PROG without modification.\n"
+"  -txt_phelp PROG: Format the output of PROG -help for simple text.\n"
+"  -sphinx_phelp PROG: Format the output of PROG -help in a sphinxized way.\n"
+"  -asphinx_phelp PROG: Format the output of PROG -help in an auto sphinxized\n"
+"                       way.\n"
+"  -doc_2_txt: Format AFNI markups from  -file/-files/-stdin content for text\n"
+"              output.\n"
+"  -doc_2_spx: Format AFNI markups from  -file/-files/-stdin content for\n"
+"              Sphinx output.\n"
+"  -hdoc_2_txt PNAME: Format program help output in  -file/-files/-stdin \n"
+"              content for text output. PNAME is needed wherever the program\n"
+"              name is needed in the output.\n"
+"  -hdoc_2_spx PNAME: Format program help output in  -file/-files/-stdin \n"
+"              content for Sphinx output. PNAME is needed wherever the program\n"
+"              name is needed in the output.\n"
+"  -hdoc_2_aspx PNAME: Format program help output in  -file/-files/-stdin  \n"
+"              content for Sphinx output with autoformatting of options.\n"
+"              PNAME is needed wherever the program name is needed in the \n"
+"              output.:LR:\n"
+"              Now, why use such an option as opposed to -asphinx_phelp ?\n"
+"              That's because the -help option in some programs cannot handle\n"
+"              any special markup within it so we write out that string as is\n"
+"              to standard out and pipe it to apsearch with:LIT:\n"
+"              3dinfo -h_raw | apsearch -hdoc_2_aspx 3dinfo -\n\n"
+"  -race_check PNAME RMAX: Debugging option to test for race conditions where\n"
+"              apsearch calls a program which for some reason ends up calling\n"
+"              it back until you chew up all allowed processes -- not fun --!\n"
+"              This program will now check for such recursive craziness using\n"
+"              Rick Reynold's afni_util.py program. To see it in action, \n"
+"              create the following script and call it @rory:LIT:\n"
+"                 #!/bin/tcsh -f\n"
+"                 echo \"Called! `date`\"\n"
+"                 apsearch -DSUMA_CountProcs_Verb=YES -race_check `basename $0`\n"
+"\n"
+"              @rory should be executable and in your path.\n"
+"              Now run @rory and watch it go.\n\n"
+"  -doc_markup_sample: Shown an example of the types of markups available for\n"
+"                      the documentation.\n"
 "  -all_afni_help: Search for WORD in all afni help files.\n"
 "                  This option is not all that clever at the moment.\n"
 "  -all_popts PROG: TRY to guess at all the options for PROG\n"
@@ -161,7 +235,6 @@ void apsearch_usage(int detail)
 "  -cs: Case sensitive search\n"
 "  -global_help: Show help for global options.\n"
 "  -gopts_help:  Show help for global options.\n"
-"  -help: You're looking at it.\n"
 "  -max_hits MH: Return best MH hits only. Default MH = 3.\n"
 "                Use -1 to get all results back.\n"
 "  -m MH: Abbreviated version of -max_hits MH.\n"
@@ -253,6 +326,15 @@ void apsearch_usage(int detail)
 "-wild_files_ci: When searching for unique set, use case insensitive matching\n"
 "-test_unique_str: Run debugging tests for function unique_str().\n"
 "\n"
+"For hard coders only:\n"
+"=====================\n"
+"-C_all_prog_opt_array : Output all program options as an array of C structs.\n"
+"                        Debugging is output to stderr, the beef is in stdout.\n"
+"-C_prog_opt_array PROG: Insert/update PROG's options in an array of C \n"
+"                        and output the results to stdout as for\n"
+"                        option -C_all_prog_opt_array\n\n"
+"            Example:    apsearch -C_prog_opt_array 3dToyProg > prog_opts.c\n"
+"\n"
 "Examples:\n"
 "=========\n"
 " 1- Search help output of program whereami for the word '-atlas'\n"
@@ -301,12 +383,13 @@ void apsearch_usage(int detail)
 "\n"
 "Global Options:\n"
 "===============\n"
-"%s", 
+"%s\n%s", 
    THD_helpdir(0),
-   detail > 1 ? get_gopt_help():""); 
+   detail > 1 ? get_gopt_help():"",
+   detail > 1 ? SUMA_Offset_SLines(get_help_help(),2):""); 
    PRINT_COMPILE_DATE ;
    }
-   return;
+   return 0;
 }
 
 
@@ -341,8 +424,11 @@ char *text_from_stdin(int *nread)
          strcat(txt, lbuf); nchar += nnew;
       }
    } while (!ex);
-
-   txt = (char *)realloc(txt, sizeof(char)*nchar);
+   
+   
+   txt = (char *)realloc(txt, sizeof(char)*(1+nchar));
+   txt[nchar]='\0';
+   
    if (nread) *nread = nchar;
    
    return(txt); 
@@ -453,28 +539,37 @@ int main(int argc, char **argv)
        compcom = 0, shtp = 0;
    float *ws_score=NULL, last_score=-1.0;
    char *fname=NULL, *text=NULL, *prog=NULL, *word="Ma fich haga", **ws=NULL, 
-         *all_popts=NULL, *popt=NULL, stdinflag[] = " [+.-STDIN-.+] ";
+         *all_popts=NULL, *popt=NULL, stdinflag[] = " [+.-STDIN-.+] ", 
+         *pname=NULL;
    THD_string_array *fnamev = NULL;
    APPROX_STR_DIFF *D=NULL;
    THD_string_array *sar = NULL;
    byte ci = 1;
    char *wild_list=NULL, **wglob=NULL, **wsort=NULL;
-   int nglob, nsort, *isrt=NULL, wild_noext=0, 
+   int nglob, nsort, *isrt=NULL, wild_noext=0, nproc=0,
        wild_all_files = 0, wild_orig_name = 0, wild_ci=0;
-   
+   TFORM spx_tar = TFORM_NOT_SET;
 
    mainENTRY("apsearch main"); machdep() ; 
-      
+   
+   /* Check for race conditions, but do allow this program to call itself once
+   to accomodate the automatic handling of -h_apsx in mainENTRY(). */
+   if ((nproc = count_procs("apsearch")) > 2) {
+      ERROR_message("Race condition detected. I'm out");
+      exit(1);
+   }
+   
    max_hits = 3;
    test_only=0;
    min_different_hits = -1;
    if (argc <= 1) {
-      apsearch_usage(0);
+      apsearch_usage(TXT, 0);
       return(1); 
    }
    
    iarg = 1 ; 
    while( iarg < argc ){
+      CHECK_HELP(argv[iarg], apsearch_usage);
       if (strcmp(argv[iarg],"-ci") == 0) { 
          ci = 1; 
          ++iarg;
@@ -576,16 +671,28 @@ int main(int argc, char **argv)
       "Global Options: options available to most AFNI programs, but usually\n"
       "                not found in the -help output.\n"
       "--------------------------------------------------------------------\n"
-             "%s", get_gopt_help());
+             "%s\n%s", SUMA_Offset_SLines(get_help_help(),2), get_gopt_help());
          return(0); 
       }
 
-      if (strcmp(argv[iarg],"-help") == 0 ||
-          strcmp(argv[iarg],"-h") == 0) { 
-         apsearch_usage(strlen(argv[iarg]) > 3 ? 2:1);
-         return(0); 
+      if (strcmp(argv[iarg],"-race_check") == 0) { 
+         char sbuf[100];
+         ++iarg;
+         if (iarg >= argc) {
+            fprintf( stderr,
+                     "** Error: Need a program name after -race_check\n"); 
+            return(1);
+         }
+         sprintf(sbuf,"%s -race_test",argv[iarg]);
+         fprintf(stderr,"Calling %s after a sec. nap\n", sbuf);
+         NI_sleep(1000);
+         system(sbuf);
+         ++iarg;
+         continue; 
       }
 
+      
+
       if (strcmp(argv[iarg],"-file") == 0) { 
          ++iarg;
          if (iarg >= argc) {
@@ -598,6 +705,113 @@ int main(int argc, char **argv)
          continue; 
       }
 
+      if (strcmp(argv[iarg],"-has-h_raw") == 0) { 
+         char *s=NULL;
+         int ans;
+         
+         ++iarg;
+         if (iarg >= argc) {
+            fprintf( stderr,
+               "** Error: Need a program name after"
+               " -has-h_raw\n");
+            return(1);
+         }
+         ans = program_supports(argv[iarg], "-h_raw", NULL, 1);
+         fprintf(stdout, "%d\n", ans);
+         return(0);
+      }
+      
+      if (strcmp(argv[iarg],"-sphinx_phelp") == 0 ||
+          strcmp(argv[iarg],"-txt_phelp") == 0 ||
+          strcmp(argv[iarg],"-raw_phelp") == 0 ||
+          strcmp(argv[iarg],"-asphinx_phelp") == 0) { 
+         TFORM form=NO_FORMAT;
+         char *s=NULL;
+         ++iarg;
+         if (iarg >= argc) {
+            fprintf( stderr,
+               "** Error: Need a program name after"
+               " -sphinx_phelp/-txt_phelp/-raw_phelp\n");
+            return(1);
+         }
+         
+              if (strcmp(argv[iarg-1],"-txt_phelp") == 0) form = TXT;
+         else if (strcmp(argv[iarg-1],"-sphinx_phelp") == 0) form = SPX;
+         else if (strcmp(argv[iarg-1],"-asphinx_phelp") == 0) form = ASPX;
+         else if (strcmp(argv[iarg-1],"-raw_phelp") == 0) form = NO_FORMAT;
+         else {
+            ERROR_message("Who wrote this thing?!?");
+            return(1);
+         }
+         if ((s = phelp(argv[iarg], form, 0))) {
+            fprintf(stdout, "%s", s);
+            free(s); s = NULL;
+         }
+         ++iarg;
+         return(0);
+         continue; 
+      }
+      
+      
+      
+      if (!strcmp(argv[iarg],"-doc_markup_sample")) {
+         SUMA_Sphinx_String_Edit_Help(NULL);
+         ++iarg;
+         return(0);
+         continue; 
+      }
+      
+      if (!strcmp(argv[iarg],"-doc_2_txt")) {
+         spx_tar = TXT;
+         ++iarg; continue;
+      }
+      
+      if (!strcmp(argv[iarg],"-doc_2_spx")) {
+         spx_tar = SPX;
+         ++iarg; continue;
+      }
+      
+      if (!strcmp(argv[iarg],"-doc_2_aspx")) {
+         spx_tar = ASPX;
+         ++iarg; continue;
+      }
+      
+      if (!strcmp(argv[iarg],"-hdoc_2_txt")) {
+         ++iarg;
+         if (iarg >= argc || !strcmp(argv[iarg],"-")) {
+            fprintf( stderr,
+                     "** Error: Need a program name after -hdoc_*\n"); return(1);
+         }
+         pname = argv[iarg];
+         spx_tar = TXT;
+         ++iarg; continue;
+      }
+      
+      if (!strcmp(argv[iarg],"-hdoc_2_spx")) {
+         ++iarg;
+         if (iarg >= argc || !strcmp(argv[iarg],"-")) {
+            fprintf( stderr,
+                     "** Error: Need a program name after -hdoc_*\n"); return(1);
+         }
+         pname = argv[iarg];
+         
+         spx_tar = SPX;
+         ++iarg; continue;
+      }
+      
+      if (!strcmp(argv[iarg],"-hdoc_2_aspx")) {
+         ++iarg;
+         if (iarg >= argc || !strcmp(argv[iarg],"-")) {
+            fprintf( stderr,
+                     "** Error: Need a program name after -hdoc_*\n"); return(1);
+         }
+         pname = argv[iarg];
+         
+         spx_tar = ASPX;
+         ++iarg; continue;
+      }
+      
+      
       if (strcmp(argv[iarg],"-files") == 0) { 
          ++iarg;
          if (iarg >= argc) {
@@ -683,7 +897,7 @@ int main(int argc, char **argv)
                      "** Error: Need program name after -web_prog_help\n"); 
                      return(1);
          }
-         web_prog_help(argv[iarg]);
+         web_prog_help(argv[iarg],0);
          return(0);
          continue; 
       }
@@ -798,6 +1012,27 @@ int main(int argc, char **argv)
          continue; 
       }
       
+      if (strcmp(argv[iarg],"-C_all_prog_opt_array") == 0) {
+         progopt_C_array(NULL, 1, NULL, 1);
+         return(0);
+         ++iarg; 
+         continue;
+      }
+      
+      if (strcmp(argv[iarg],"-C_prog_opt_array") == 0) {
+         ++iarg;
+         if (iarg >= argc) {
+            fprintf( stderr,
+               "** Error: Need program name after -C_prog_opt_array\n");
+            return(1);
+         }
+         progopt_C_array(NULL, 1, argv[iarg], 1);
+         return(0);
+         ++iarg; 
+         continue;
+      }
+      
+      
       if (strcmp(argv[iarg],"-bash") == 0) {
          shtp = 1;
          ++iarg; 
@@ -996,41 +1231,84 @@ int main(int argc, char **argv)
    }
    
    if ((fnamev || fname || text || prog || popt || all_popts)) {
-      if (!strcmp(word,"Ma fich haga")) {
+      if (!strcmp(word,"Ma fich haga") && spx_tar == TFORM_NOT_SET) {
          ERROR_message(
             "I'd search the world over for you, if only you gave me -word");
          return 1;
       }
       if (fnamev) {
          fprintf(stderr,"Have %d files\n", fnamev->num);
-
-         sar = approx_str_sort_Ntfile(
-                     fnamev->ar, fnamev->num, word, ci, &ws_score,
-                            NULL,
-                            &D, 0, '\0');
-         ws = sar->ar; N_ws = sar->num;
+         if (spx_tar != TFORM_NOT_SET) {
+            for (i=0; i<fnamev->num; ++i) {
+               char *sso=SUMA_Sphinx_File_Edit(fnamev->ar[i], spx_tar, 0);
+               if (sso) {
+                  fprintf(stdout,"%s", sso); free(sso); sso = NULL;
+               } else {
+                  ERROR_message("Failed to sphinx edit string in %s", 
+                                 fnamev->ar[i]);
+                  return 1;
+               }
+            }
+            return 0;
+         } else {
+            sar = approx_str_sort_Ntfile(
+                        fnamev->ar, fnamev->num, word, ci, &ws_score,
+                               NULL,
+                               &D, 0, '\0');
+            ws = sar->ar; N_ws = sar->num;
+         }
       } else if (fname) {
          if (strcmp(fname,stdinflag)) {
-            ws = approx_str_sort_tfile(fname, &N_ws, word, 
+            if (spx_tar != TFORM_NOT_SET) {
+               char *sso=NULL;
+               if (!pname) {
+                  sso = SUMA_Sphinx_File_Edit(fname, spx_tar, 0);
+               } else {
+                  sso = AFNI_suck_file(fname);
+                  sso = sphelp(pname, &sso, spx_tar, 0);
+               }
+               if (sso) {
+                  fprintf(stdout,"%s", sso); free(sso); sso = NULL;
+               } else {
+                  ERROR_message("Failed to sphinx edit string in %s", fname);
+                  return 1;
+               }
+               return 0;
+            } else {
+               ws = approx_str_sort_tfile(fname, 0, &N_ws, word, 
                          ci, &ws_score,
                          NULL, &D, 1, '\0');
+            }
          } else {
             char *stdtext=NULL;
             if (!(stdtext = text_from_stdin(&N_ws))) {
                ERROR_message("Failed to read from stdin");
                return 0;
             }
-            ws = approx_str_sort_text(stdtext, &N_ws, word, 
-                            ci, &ws_score,
-                            NULL, &D, '\0'); 
-            free(stdtext); stdtext=NULL;
+            if (spx_tar != TFORM_NOT_SET) {
+               if (!pname) {
+                  stdtext = SUMA_Sphinx_String_Edit(&stdtext, spx_tar, 0);
+               } else {
+                  stdtext = sphelp(pname, &stdtext, spx_tar, 0);
+               }
+               if (stdtext) {
+                  fprintf(stdout,"%s", stdtext);
+                  free(stdtext); stdtext=NULL;
+               }
+               return 0;
+            } else {
+               ws = approx_str_sort_text(stdtext, &N_ws, word, 
+                               ci, &ws_score,
+                               NULL, &D, '\0');
+               free(stdtext); stdtext=NULL;
+            } 
          }
       } else if (text) {
          ws = approx_str_sort_text(text, &N_ws, word, 
                             ci, &ws_score,
                             NULL, &D, '\0');
       } else if (prog) {
-         ws = approx_str_sort_phelp(prog, &N_ws, word, 
+         ws = approx_str_sort_phelp(prog, 0, &N_ws, word, 
                             ci, &ws_score,
                             NULL, &D, 1, '\\');
       } else if (popt) {
@@ -1038,7 +1316,7 @@ int main(int argc, char **argv)
          return 0;
       } else if (all_popts) {
          /* one can also use print_prog_options(all_popts); return(0); */
-         ws = approx_str_sort_all_popts(all_popts, &N_ws, 
+         ws = approx_str_sort_all_popts(all_popts, 0, &N_ws, 
                             ci, &ws_score,
                             NULL, &D, uopts, 1, '\\');
       }
