@@ -10,6 +10,7 @@
 #include <string.h>
 #include "cs.h"
 #include "eispack.h"
+#include "Aomp.h"
 
 #ifdef isfinite
 # define IS_GOOD_FLOAT(x) isfinite(x)
@@ -821,22 +822,22 @@ void svd_double( int m, int n, double *a, double *s, double *u, double *v )
      if( u != NULL ){
        double *cc = (double *)calloc(sizeof(double),m*n) ;
 #pragma omp critical
-       (void)memcpy( cc , u , sizeof(double)*m*n ) ;
+       (void)AAmemcpy( cc , u , sizeof(double)*m*n ) ;
        for( jj=0 ; jj < n ; jj++ ){
          kk = iv[jj] ;  /* where the new jj-th col came from */
 #pragma omp critical
-         (void)memcpy( u+jj*m , cc+kk*m , sizeof(double)*m ) ;
+         (void)AAmemcpy( u+jj*m , cc+kk*m , sizeof(double)*m ) ;
        }
        free((void *)cc) ;
      }
      if( v != NULL ){
        double *cc = (double *)calloc(sizeof(double),n*n) ;
 #pragma omp critical
-       (void)memcpy( cc , v , sizeof(double)*n*n ) ;
+       (void)AAmemcpy( cc , v , sizeof(double)*n*n ) ;
        for( jj=0 ; jj < n ; jj++ ){
          kk = iv[jj] ;
 #pragma omp critical
-         (void)memcpy( v+jj*n , cc+kk*n , sizeof(double)*n ) ;
+         (void)AAmemcpy( v+jj*n , cc+kk*n , sizeof(double)*n ) ;
        }
        free((void *)cc) ;
      }
@@ -885,7 +886,7 @@ void svd_double_ata( int m, int n, double *a, double *s, double *u, double *v )
 
    if( v != NULL ){
 #pragma omp critical
-     (void)memcpy( v , ata , sizeof(double)*n*n ) ;
+     AAmemcpy( v , ata , sizeof(double)*n*n ) ;
    }
 
    /* manufacture U from A and V (which is in ata, recall):
