@@ -421,6 +421,7 @@ long long mcw_malloc_total(void)  /* 01 Feb 2007 */
 
 extern int THD_is_file( char * ) ;
 extern void qsort_intint( int , int * , int * ) ;
+static int size_sort = 0;
 
 void mcw_malloc_dump(void)
 {
@@ -478,7 +479,8 @@ void mcw_malloc_dump(void)
    for( ii=jj=0 ; jj < SLOTS ; jj++ ){
       for( kk=0 ; kk < nhtab[jj] ; kk++ ){
          if( htab[jj][kk].pmt != NULL ){
-            ss[ii] = htab[jj][kk].pss ;   /* save serial number */
+            if (size_sort) ss[ii] =  htab[jj][kk].psz ; /* save size */
+            else ss[ii] = htab[jj][kk].pss ;   /* save serial number */
             jk[ii] = JBASE*jj + kk ;      /* save jj and kk */
             ii++ ;
          }
@@ -536,6 +538,13 @@ void mcw_malloc_dump(void)
  return ;
 }
 
+/* put below mcw_malloc_dump to appease solaris   30 Dec 2013 [rickr] */
+void mcw_malloc_dump_sort(int opt) {
+   if (opt == 1) size_sort = 1;
+   mcw_malloc_dump();
+   if (opt == 1) size_sort = 0;
+}
+
 /*----------------------------------------------------------------
   Turn on use of the tracking routines
 ------------------------------------------------------------------*/
@@ -638,6 +647,20 @@ void * mcw_calloc( size_t n , size_t m , char *fnam , int lnum )
    else               return calloc( n , m ) ;
 }
 
+#ifndef DONT_USE_MCW_MALLOC
+/*-----------------------------------------------------------------
+    Is this pointer OK?
+-------------------------------------------------------------------*/
+
+int mcw_malloc_OK( void *fred )
+{
+   mallitem *ip ;
+   if( fred == NULL || !use_tracking ) return 1 ;
+   ip = shift_tracker(fred) ;
+   return (ip != NULL) ;
+}
+#endif
+
 /*-----------------------------------------------------------------
     The actual replacment for free()
 -------------------------------------------------------------------*/
