@@ -23,13 +23,14 @@ static byte OK_wrap = 0;
 static byte WrapZero = 0;
 void mri_Set_KO_catwrap(void) { OK_wrap = 0; return; }
 void mri_Set_OK_catwrap(void) { OK_wrap = 1; return; }
+void mri_Set_OK_catrandwrap(void) { OK_wrap = 2; return; }
 void mri_Set_OK_WrapZero(void) { WrapZero = 1; return; }
 void mri_Set_KO_WrapZero(void) { WrapZero = 0; return; }
 
-MRI_IMAGE * mri_cat2D(  int mx , int my , int gap , 
+MRI_IMAGE * mri_cat2D(  int mx , int my , int gap ,
                         void *gapval , MRI_IMARR *imar )
 {
-   int nx , ny , ii , jj , kind , ij , nxout , nyout , ijoff , jout,iout ;
+   int nx , ny , ii , jj , kind , ij , nxout , nyout , ijoff , jout,iout, iijj ;
    MRI_IMAGE *imout , *imin=NULL ;
    void *vout ;
 
@@ -37,9 +38,9 @@ ENTRY("mri_cat2D") ;
 
    /*--- sanity checks ---*/
 
-   if(   mx < 1 || my < 1 || imar == NULL || 
-         (!OK_wrap && imar->num < mx*my) ) 
-      RETURN( NULL );   
+   if(   mx < 1 || my < 1 || imar == NULL ||
+         (!OK_wrap && imar->num < mx*my) )
+      RETURN( NULL );
    if( gap < 0 || (gap > 0 && gapval == NULL) )                RETURN( NULL );
 
    for( ij=0 ; ij < mx*my ; ij++ ){     /* find first non-empty image */
@@ -60,7 +61,21 @@ ENTRY("mri_cat2D") ;
 
 
    for( ij=0 ; ij < mx*my ; ij++ ){     /* check for consistency */
-      imin = IMARR_SUBIMAGE(imar,ij%imar->num) ;
+      switch (OK_wrap) {
+         default:
+         case 0:
+            iijj = ij;
+            if (iijj >= imar->num) iijj = imar->num-1;
+            break;
+          case 1:
+            iijj = ij%imar->num;
+            break;
+         case 2:
+            if (ij < imar->num) iijj = ij;
+            else iijj = (int)(lrand48() % (imar->num));
+            break;
+      }
+      imin = IMARR_SUBIMAGE(imar,iijj) ;
       if( imin != NULL &&
           (imin->kind != kind || imin->nx != nx || imin->ny != ny) )
          RETURN( NULL );
@@ -71,13 +86,28 @@ ENTRY("mri_cat2D") ;
    imout = mri_new( nxout , nyout , kind ) ;
    vout  = mri_data_pointer( imout ) ;
 
-
    ij = 0 ;
    for( jj=0 ; jj < my ; jj++ ){            /* loop over rows */
       for( ii=0 ; ii < mx ; ii++ , ij++ ){  /* loop over columns */
 
          if (WrapZero && ij >= imar->num) imin = NULL;
-         else imin  = IMARR_SUBIMAGE(imar,ij%imar->num) ;
+         else {
+            switch (OK_wrap) {
+               default:
+               case 0:
+                  iijj = ij;
+                  if (iijj >= imar->num) iijj = imar->num-1;
+                  break;
+               case 1:
+                  iijj = ij%imar->num;
+                  break;
+               case 2:
+                  if (ij < imar->num) iijj = ij;
+                  else iijj = (int)(lrand48() % (imar->num));
+                  break;
+            }
+            imin  = IMARR_SUBIMAGE(imar,iijj) ;
+         }
          ijoff = ii * (nx+gap) + jj * (ny+gap) * nxout ;
 
          /*--- NULL image ==> fill this spot with zeroes ---*/
@@ -96,6 +126,12 @@ ENTRY("mri_cat2D") ;
                      (void) memset( pout+(3*ijoff) , 0 , sizeof(byte)*(3*nx) ) ;
                } break ;
 
+               case MRI_rgba:{                      /* 09 Dec 2014 */
+                  rgba *pout = (rgba *)vout ;
+                  for( jout=0 ; jout < ny ; jout++ , ijoff+=nxout )
+                     (void) memset( pout+ijoff , 0 , sizeof(rgba)*nx ) ;
+               } break ;
+
                case MRI_short:{
                   short *pout = ((short *) vout);
                   for( jout=0 ; jout < ny ; jout++ , ijoff+=nxout )
@@ -148,6 +184,13 @@ ENTRY("mri_cat2D") ;
                      memcpy( pout+(3*ijoff) , pin , sizeof(byte)*(3*nx) ) , pin += 3*nx ;
                } break ;
 
+               case MRI_rgba:{                              /* 09 Dec 2014 */
+                  rgba *pout = (rgba *)vout ,
+                       *pin  = MRI_RGBA_PTR(imin) ;
+                  for( jout=0 ; jout < ny ; jout++ , ijoff+=nxout )
+                     memcpy( pout+ijoff , pin , sizeof(rgba)*nx ) , pin += nx ;
+               } break ;
+
                case MRI_short:{
                   short *pout = ((short *) vout) ,
                         *pin  =  (short *) MRI_SHORT_PTR(imin) ;
@@ -202,6 +245,11 @@ ENTRY("mri_cat2D") ;
                for( ij=0 ; ij < ii ; ij++ ) pout[ij+ijoff] = gval ;
             } break ;
 
+            case MRI_rgba:{      /* 09 Dec 2014 */
+              rgba gval = *((rgba *)gapval) , *pout = (rgba *)vout ;
+              for( ij=0 ; ij < ii ; ij++ ) pout[ij+ijoff] = gval ;
+            } break ;
+
             case MRI_rgb:{       /* 11 Feb 1999 */
                byte rval = *(((byte *)gapval)  ) ,
                     gval = *(((byte *)gapval)+1) ,
@@ -252,6 +300,12 @@ ENTRY("mri_cat2D") ;
                   for( jj=0 ; jj < nyout ; jj++ ) pout[jj*nxout+ijoff] = gval ;
             } break ;
 
+            case MRI_rgba:{             /* 09 Dec 2014 */
+               rgba gval = *((rgba *)gapval) , *pout = ((rgba *) vout) ;
+               for( ij=0 ; ij < gap ; ij++ , ijoff++ )
+                  for( jj=0 ; jj < nyout ; jj++ ) pout[jj*nxout+ijoff] = gval ;
+            } break ;
+
             case MRI_rgb:{              /* 11 Feb 1999 */
                byte rval = *(((byte *)gapval)  ) ,
                     gval = *(((byte *)gapval)+1) ,
