@@ -149,12 +149,14 @@ void usage_1dDW_Grad_o_Mat(int detail)
 "                           top with all zeros.\n"
 "    -in_bvals BVAL_IN     :BVAL_IN is a file of b-values, such as the 'bval'\n"
 "                           file generated by dcm2nii.\n"
-"    -bmax_ref THRESH      :BVAL_IN is a scalar number below which b-values\n"
-"                           are considered `zero' or non-reference; \n"
-"                           sometimes, for the reference images, the scanner\n"
-"                           has b=5 s/mm^2 instead of b=0 strictly. One can\n"
-"                           still flag as being a reference image and filter\n"
-"                           it out, using, for here, '-bvals 5.1'\n"
+"    -bmax_ref THRESH      :THRESH is a scalar number below which b-values\n"
+"                           (in BVAL_IN) are considered `zero' or reference.\n"
+"                           Sometimes, for the reference images, the scanner\n"
+"                           has a value like b=5 s/mm^2, instead of strictly\n"
+"                           b=0 strictly. One can still flag such values as\n"
+"                           being associated with a reference image and\n"
+"                           trim it out, using, for the example case here, \n"
+"                           '-bmax_ref 5.1'.\n"
 "    -out_bval_col         :switch to put a column of the bvalues as the\n"
 "                           first column in the output data.\n"
 "\n"
