@@ -102,6 +102,12 @@ int main( int argc , char * argv[] )
 "  series.  This program is **heavily** based on the existing\n"
 "  3dBandPass by RW Cox, with the amendments to calculate RSFC\n"
 "  parameters written by PA Taylor (July, 2012).\n"
+"  This program is part of FATCAT (Taylor & Saad, 2013) in AFNI. Importantly,\n"
+"  its functionality can be included in the `afni_proc.py' processing-script \n"
+"  generator; see that program's help file for an example including RSFC\n"
+"  and spectral parameter calculation via the `-regress_RSFC' option.\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
 "\n"
 "  All options of 3dBandPass may be used here (with a couple other\n"
 "  parameter options, as well): essentially, the motivation of this\n"
@@ -118,8 +124,11 @@ int main( int argc , char * argv[] )
 "  For more information about each RSFC parameter, see, e.g.:   \n"
 "  ALFF/mALFF -- Zang et al. (2007),\n"
 "  fALFF --      Zou et al. (2008),\n"
-"  RSFA --       Kannurpatti & Biswal (2008).\n\n\n"
-"****Usage: 3dRSFC [options] fbot ftop dataset\n"
+"  RSFA --       Kannurpatti & Biswal (2008).\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
+"\n"
+" + USAGE: 3dRSFC [options] fbot ftop dataset\n"
 "\n"
 "* One function of this program is to prepare datasets for input\n"
 "   to 3dSetupGroupInCorr.  Other uses are left to your imagination.\n"
@@ -162,9 +171,9 @@ int main( int argc , char * argv[] )
 "\n"
 "* The output dataset is stored in float format.\n"
 "\n"
-"* The order of processing steps is the following (most are optional), \n"
-"  and for the LFFs, the bandpass is done between the specified fbot and ftop,\n"
-"  while for the `whole spectrum' (i.e., fALFF denominator)  the `bandpass' is:\n"
+"* The order of processing steps is the following (most are optional), and\n"
+"  for the LFFs, the bandpass is done between the specified fbot and ftop,\n"
+"  while for the `whole spectrum' (i.e., fALFF denominator) the bandpass is:\n"
 "  done only to exclude the time series mean and the Nyquist frequency:\n"
 " (0) Check time series for initial transients [does not alter data]\n"
 " (1) Despiking of each time series\n"
@@ -179,6 +188,7 @@ int main( int argc , char * argv[] )
 " (8) L2 normalization         [will be fast.]\n"
 " (9) Calculate spectrum and amplitudes, for RSFC parameters.\n"
 "\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
 "--------\n"
 "OPTIONS:\n"
 "--------\n"
@@ -217,10 +227,11 @@ int main( int argc , char * argv[] )
 "                   series would be, e.g., ppp_LFF+orig.*, and the parameter\n"
 "                   outputs are named with obvious suffices.\n"
 " -quiet          = Turn off the fun and informative messages. (Why?)\n"
-" -no_rs_out      = Don't output processed time series-- just output parameters\n"
-"                   (not recommended since the point of calculating RSFC params\n"
-"                   here is to have them be quite related to the time series\n"
-"                   themselves which are used for further analysis)."
+" -no_rs_out      = Don't output processed time series-- just output\n"
+"                   parameters (not recommended, since the point of\n"
+"                   calculating RSFC params here is to have them be quite\n"
+"                   related to the time series themselves which are used for\n"
+"                   further analysis)."
 " -un_bp_out      = Output the un-bandpassed series as well (default is not \n"
 "                   to).  Name would be, e.g., ppp_unBP+orig.* .\n"
 "                   with suffix `_unBP'.\n"
@@ -239,11 +250,20 @@ int main( int argc , char * argv[] )
 "                   ++ Or set AFNI_SKIP_SATCHECK to YES.\n"
 "                   ++ Initial transients won't be handled well by the\n"
 "                      bandpassing algorithm, and in addition may seriously\n"
-"                      contaminate any further processing, such as inter-voxel\n"
-"                      correlations via InstaCorr.\n"
-"                   ++ No other tests are made [yet] for non-stationary behavior\n"
-"                      in the time series data.\n"
-				 ) ;
+"                      contaminate any further processing, such as inter-\n"
+"                      voxel correlations via InstaCorr.\n"
+"                   ++ No other tests are made [yet] for non-stationary \n"
+"                      behavior in the time series data.\n"
+"\n"
+"* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\n"
+"\n"
+"  If you use this program, please reference the introductory/description\n"
+"  paper for the FATCAT toolbox:\n"
+"        Taylor PA, Saad ZS (2013).  FATCAT: (An Efficient) Functional\n"
+"        And Tractographic Connectivity Analysis Toolbox. Brain \n"
+"        Connectivity 3(5):523-535.\n"
+"____________________________________________________________________________\n"
+);
 		PRINT_AFNI_OMP_USAGE(
 " 3dRSFC" ,
 " * At present, the only part of 3dRSFC that is parallelized is the\n"
