@@ -53,17 +53,19 @@ typedef struct {
    int MINI_PROB_NM;              //  "-mini_num"
    int CHOOSE_SEED;               //  "-choose_seed"
    int OUTPUT_TRK;                //  "-no_trk_out"
+   int OUT_INDIPAIR;              //  "-no_indipair_out"
 
    // minorly used control stuff, mostly default
    char *NAMEIN_outmode;          //  "-tract_out_mode"
    int dump_opts;                 //  "-write_opts"
    int ROIS_OUT;                  //  "-write_rois"
-   int DUMP_ORIG_LABS;            //  "-lab_orig_rois"
+   int DUMP_ORIG_LABS;            //  "-dump_lab_consec"
    int POST;                      //  "-posteriori"
    int DUMP_TYPE;                 //  "-dump_rois"
+   int DUMP_with_LABELS;          //  "-dump_no_labtab"
    int RECORD_ORIG;               //  "-rec_orig"
-   int PAIRPOWER;                 //  "-pair_out_int"
-   int EXTRA_TR_PAR;              //  "-pair_out_int"
+   int PAIRPOWER;                 //  "-pair_out_power"
+   int EXTRA_TR_PAR;              //  "-extra_tr_par"
 
    // EXPIRED OPTIONS, just gives message/error:
    // "-cut_at_rois"
