@@ -291,6 +291,7 @@ Notes:
 basic informational options:
 
    -help                        : show this help
+   -help_basis                  : describe various basis functions
    -hist                        : show the module history
    -show_valid_opts             : show all valid options
    -ver                         : show the version number
@@ -814,6 +815,106 @@ R Reynolds    December 2008
 =============================================================================
 """
 
+
+g_help_basis_string = """
+=============================================================================
+descriptions of various basis functions, as applied by 3dDeconvolve
+-----------------------------------------------------------------------------
+
+  GAM                   : same as GAM(p,q), where p=8.6, q=0.547
+               duration : approx. 12 seconds
+  GAM(p)                : INVALID
+  GAM(p,q)              : (t/(p*q))^p * exp(p-t/q)
+  GAM(p,q,d)            : convolve with d-second boxcar
+               defaults : p=8.6, q=0.547
+               duration : approx. 12+d seconds
+ 
+                   peak : peak = 1.0, default peak @ t=4.7
+
+  ---------------------------------------------------------------------------
+
+  BLOCK                 : INVALID
+  BLOCK(d)              : stimulus duration d (convolve with d-second boxcar)
+                   peak : peak of 1.0 (for d=1) @ t=4.5, max peak of ~5.4
+               duration : approx. 15+d seconds
+  BLOCK(d,p)            : stimulus duration d, peak p
+                   peak : peak = p, @t~=4+d/2
+
+  ---------------------------------------------------------------------------
+
+  duration modulation - individual stimulus durations included in timing file
+
+  dmBLOCK, dmBLOCK(0)   : akin to BLOCK(d), where d varies per stimulus event
+                   peak : see BLOCK(d), maybe dur=peak in [0,1], then max ~5.4
+               duration : see BLOCK(d), approx 15+d seconds
+  dmBLOCK(p)      p > 0 : all peaks equal to p, regardless of duration
+                          (same as dmUBLOCK(p))
+                  p < 0 : same as p=0, or dmBLOCK(0)
+
+  dmUBLOCK, dmUBLOCK(0) : basically equals dmBLOCK/5.4 (so max peak = 1)
+                   peak : d=1:p=1/5.4, to max d=15:p=1 (i.e. BLOCK(d)/5.4)
+  dmUBLOCK(p)     p > 0 : all peaks = p, regardless of duration
+                          (same as dmBLOCK(p))
+                  p < 0 : like p=0, but scale so peak = 1 for dur=|p|
+                          e.g. dmUBLOCK(-5) will have peak = 1.0 for a 5s dur,
+                               i.e ~= dmBLOCK/4.0
+
+  ---------------------------------------------------------------------------
+
+  TENT(b,c,n)           : n tents/regressors, spanning b..c sec after stimulus
+                        : half-tent at time b, half-tent at time c
+                        : tents are centered at intervals of length (c-b)/(n-1)
+                          --> so there are n-1 intervals for n tents
+                   peak : peaks = 1 at interval centers
+               duration : c-b seconds
+
+  TENTzero(b,c,n)       : n-2 tents, same as above but ignoring first and last
+                          --> akin to assuming first and last betas are 0
+                        : same as TENT(b+v,c-v,n-2), where v = (c-b)/(n-1)
+
+  ---------------------------------------------------------------------------
+
+  SPMG1                 : 1-regressor SPM gamma variate
+               duration : positive lobe: 0..12 sec, undershoot: 12..24 sec
+                   peak : 0.175 @ t=5.0, -0.0156 @ t=15.7
+  SPMG, SPMG2           : 2-regressor SPM gamma variate
+                        : with derivative, to account for small temporal shift
+  SPMG3                 : 3-regressor SPM gamma variate
+                        : with dispersion curve
+
+  ---------------------------------------------------------------------------
+
+  WAV                   : 1-regressor WAV function from waver
+  WAV(d)                : convolves with stimulus duration d, in seconds
+  WAV(d,D,R,F,Uf,Ur)    : includes D=delay time, R=rise time, F=fall time,
+                          Uf=undershoot fraction, Ur=undershoot restore time
+                        : defaults WAV(d,2,4,6,0.2,2)
+               duration : stimulus duration d
+                   peak : peak = 1, @t=d+6, or duration+delay+rise
+             undershoot : fractional undershoot
+               consider : WAV(1,1,3,8,0.2,2)
+                          - similar to GAM, with subsequent undershoot
+
+  ---------------------------------------------------------------------------
+  example:
+
+     3dDeconvolve -nodata 200 0.1 -polort -1 -num_stimts 4      \\
+        -stim_times 1 '1D:0' GAM                                \\
+        -stim_times 2 '1D:0' 'WAV(1,1,3,8,0.2,2)'               \\
+        -stim_times 3 '1D:0' 'BLOCK(1)'                         \\
+        -stim_times 4 '1D:0' SPMG3                              \\
+        -x1D X.xmat.1D -x1D_stop
+
+     1dplot -sepscl X.xmat.1D
+
+        OR, to be more complicated:
+
+     1dplot -ynames GAM 'WAV(spec)' 'BLOCK(1)' SPMG_1 SPMG_2 SPMG_3 \\
+        -xlabel 'tenths of a second' -sepscl X.xmat.1D
+
+=============================================================================
+"""
+
 g_history = """
    timing_tool.py history:
 
@@ -857,9 +958,12 @@ g_history = """
         - removed -chrono option
           (action items are still processed chronologically)
    2.08 May 12, 2014 - default -part_init to INIT (0 not valid for -partition)
+   2.09 Sep 18, 2014 - added -help_basis to describe basis functions
+                       (mostly to clarify dmBLOCK/dmUBLOCK)
+   2.10 Oct 28, 2014 - expanded -help_basis (WAV, 3dDeconvolve, 1dplot)
 """
 
-g_version = "timing_tool.py version 2.08, May 12, 2014"
+g_version = "timing_tool.py version 2.10, Oct 28, 2014"
 
 
 
@@ -1042,13 +1146,15 @@ class ATInterface:
       self.valid_opts = OL.OptionList('valid opts')
 
       # short, terminal arguments
-      self.valid_opts.add_opt('-help', 0, [],           \
+      self.valid_opts.add_opt('-help', 0, [],
                          helpstr='display program help')
-      self.valid_opts.add_opt('-hist', 0, [],           \
+      self.valid_opts.add_opt('-help_basis', 0, [],
+                         helpstr='describe various basis functions')
+      self.valid_opts.add_opt('-hist', 0, [],
                          helpstr='display the modification history')
-      self.valid_opts.add_opt('-show_valid_opts', 0, [],\
+      self.valid_opts.add_opt('-show_valid_opts', 0, [],
                          helpstr='display all valid options')
-      self.valid_opts.add_opt('-ver', 0, [],            \
+      self.valid_opts.add_opt('-ver', 0, [],
                          helpstr='display the current version number')
 
       # action options - single data
@@ -1163,6 +1269,10 @@ class ATInterface:
          print g_help_string
          return 0
 
+      if len(sys.argv) <= 1 or '-help_basis' in sys.argv:
+         print g_help_basis_string
+         return 0
+
       if '-hist' in sys.argv:
          print g_history
          return 0
