@@ -116,6 +116,7 @@ typedef struct {
    float *prob; /*!< probability, if applicable, of being of a particular label */
    float *radius;   /*!< distance, search distance for reported label.*/ 
    char **webpage; /*!< webpages for a web-atlas for whereami location */
+   char **connpage; /*!< connection info webpages for a web-atlas for whereami location */
 } ATLAS_ZONE;
 
 typedef struct {
@@ -168,6 +169,8 @@ typedef struct {
    char *orient;  /* string to specify xyz order requests - Elsevier's web version uses "RSA"*/
    char *supp_web_info; /* string specifying base webpage for supplemental structure info */
    char *supp_web_type; /* extension suffix for webpages - pdf, html,... */
+   char *supp_conn_info; /* string specifying base webpage for supplemental connection info */
+   char *supp_conn_type; /* extension suffix for webpages - pdf, html,... */
    int atlas_found;
    ATLAS_DSET_HOLDER *adh;
 } ATLAS; /*!< All char * should be initialized when .niml file is loaded,
@@ -219,6 +222,13 @@ typedef struct {
 #define ATL_SUPP_WEB_TYPE_S(xa) ( (ATL_SUPP_WEB_TYPE(xa)) ? \
           ((xa)->supp_web_type)   : ".html" )
 
+#define ATL_SUPP_CONN_INFO(xa) ((xa) && (xa)->supp_conn_info ? 1: 0)
+#define ATL_SUPP_CONN_INFO_S(xa) ( (ATL_SUPP_CONN_INFO(xa)) ? \
+          ((xa)->supp_conn_info)   : "No supplemental info " )
+#define ATL_SUPP_CONN_TYPE(xa) ((xa)->supp_conn_type ? 1: 0)
+#define ATL_SUPP_CONN_TYPE_S(xa) ( (ATL_SUPP_CONN_TYPE(xa)) ? \
+          ((xa)->supp_conn_type)   : ".html" )
+
 #define ATL_FOUND(xa) ( (xa)  ? \
                            ((xa)->atlas_found) : 0 )
 
@@ -333,7 +343,7 @@ char **approx_str_sort_text(char *text, int *N_ws, char *str,
                             byte ci, float **sorted_score,
                             APPROX_STR_DIFF_WEIGHTS *Dwi,
                             APPROX_STR_DIFF **Dout, char join_breaks);      
-char **approx_str_sort_tfile(char *fname, int *N_ws, char *str, 
+char **approx_str_sort_tfile(char *fname, int textinname, int *N_ws, char *str, 
                             byte ci, float **sorted_score,
                             APPROX_STR_DIFF_WEIGHTS *Dwi,
                             APPROX_STR_DIFF **Dout, int verb, char join_breaks);
@@ -343,27 +353,20 @@ THD_string_array *approx_str_sort_Ntfile(
                       APPROX_STR_DIFF_WEIGHTS *Dwi,
                       APPROX_STR_DIFF **Doutp, int verb, char join_breaks);
 #define APSEARCH_TMP_PREF "__apsearch"
-char **approx_str_sort_phelp(char *prog, int *N_ws, char *str, 
+char **approx_str_sort_phelp(char *prog, int textinname, int *N_ws, char *str, 
                             byte ci, float **sorted_score,
                             APPROX_STR_DIFF_WEIGHTS *Dwi,
                             APPROX_STR_DIFF **Dout, int verb, char join_breaks);
-char **approx_str_sort_all_popts(char *prog, int *N_ws, 
+char **approx_str_sort_all_popts(char *prog, int textinname, int *N_ws, 
                             byte ci, float **sorted_score,
                             APPROX_STR_DIFF_WEIGHTS *Dwi,
                             APPROX_STR_DIFF **Dout,
                             int uopts, int verb, char join_breaks);
 char *get_updated_help_file(int force_recreate, byte verb, char *progname, 
                             int shtp);
-int prog_complete_command (char *prog, char *ofile, int shtp);
 char **approx_str_sort_readmes(char *str, int *N_r);
 char **unique_str(char **words, int N_words, byte ci, 
                   byte noae, int *N_unq, int **isort_out);
-char *find_readme_file(char *str);
-int view_text_file(char *progname);
-void view_prog_help(char *prog);
-void web_prog_help(char *prog);
-void web_class_docs(char *prog);
-int view_web_link(char *link, char *browser);
 char *approx_string_diff_info(APPROX_STR_DIFF *D,APPROX_STR_DIFF_WEIGHTS *Dwi); 
 ATLAS_SEARCH *Find_Atlas_Regions(AFNI_ATLAS *aa, AFNI_ATLAS_REGION *ur , 
                                  ATLAS_SEARCH *usethissearch);
@@ -373,7 +376,7 @@ char * Clean_Atlas_Label( char *lb);
 char * Clean_Atlas_Label_to_Prefix( char *lb);
 ATLAS_ZONE *Get_Atlas_Zone(ATLAS_QUERY *aq, int level);
 ATLAS_ZONE *Atlas_Zone(ATLAS_ZONE *zn, int level, char *label, int code, 
-                       float prob, float within, char *aname, char *webpage) ;
+                       float prob, float within, char *aname, char *webpage, char *connpage) ;
 ATLAS_ZONE *Free_Atlas_Zone(ATLAS_ZONE *zn);
 void Set_Show_Atlas_Mode(int md);
 void Show_Atlas_Zone(ATLAS_ZONE *zn, ATLAS_LIST *atlas_list);
@@ -502,6 +505,7 @@ void open_wami_webpage(void);
 int AFNI_wami_output_mode(void);
 void set_AFNI_wami_output_mode(int webflag);
 char * atlas_suppinfo_webpage(ATLAS *atlas, char *blab);
+char * atlas_suppinfo_connpage(ATLAS *atlas, char *blab);
 
 size_t CURL_read_URL_http ( char *url, char **data);
 void set_wami_minprob(float val);
